# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Document(pulumi.CustomResource):
    arn: pulumi.Output[str]
    attachments_sources: pulumi.Output[list]
    """
    One or more configuration blocks describing attachments sources to a version of a document. Defined below.

      * `key` (`str`) - The key describing the location of an attachment to a document. Valid key types include: `SourceUrl` and `S3FileUrl`
      * `name` (`str`) - The name of the document attachment file
      * `values` (`list`) - The value describing the location of an attachment to a document
    """
    content: pulumi.Output[str]
    """
    The JSON or YAML content of the document.
    """
    created_date: pulumi.Output[str]
    """
    The date the document was created.
    """
    default_version: pulumi.Output[str]
    """
    The default version of the document.
    """
    description: pulumi.Output[str]
    """
    The description of the document.
    """
    document_format: pulumi.Output[str]
    """
    The format of the document. Valid document types include: `JSON` and `YAML`
    """
    document_type: pulumi.Output[str]
    """
    The type of the document. Valid document types include: `Automation`, `Command`, `Package`, `Policy`, and `Session`
    """
    hash: pulumi.Output[str]
    """
    The sha1 or sha256 of the document content
    """
    hash_type: pulumi.Output[str]
    """
    "Sha1" "Sha256". The hashing algorithm used when hashing the content.
    """
    latest_version: pulumi.Output[str]
    """
    The latest version of the document.
    """
    name: pulumi.Output[str]
    """
    The name of the document.
    """
    owner: pulumi.Output[str]
    """
    The AWS user account of the person who created the document.
    """
    parameters: pulumi.Output[list]
    """
    The parameters that are available to this document.

      * `default_value` (`str`)
      * `description` (`str`) - The description of the document.
      * `name` (`str`) - The name of the document.
      * `type` (`str`)
    """
    permissions: pulumi.Output[dict]
    """
    Additional Permissions to attach to the document. See Permissions below for details.
    """
    platform_types: pulumi.Output[list]
    """
    A list of OS platforms compatible with this SSM document, either "Windows" or "Linux".
    """
    schema_version: pulumi.Output[str]
    """
    The schema version of the document.
    """
    status: pulumi.Output[str]
    """
    "Creating", "Active" or "Deleting". The current status of the document.
    """
    tags: pulumi.Output[dict]
    """
    A map of tags to assign to the object.
    """
    target_type: pulumi.Output[str]
    """
    The target type which defines the kinds of resources the document can run on. For example, /AWS::EC2::Instance. For a list of valid resource types, see AWS Resource Types Reference (http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html)
    """
    def __init__(__self__, resource_name, opts=None, attachments_sources=None, content=None, document_format=None, document_type=None, name=None, permissions=None, tags=None, target_type=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides an SSM Document resource

        > **NOTE on updating SSM documents:** Only documents with a schema version of 2.0
        or greater can update their content once created, see [SSM Schema Features](http://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-ssm-docs.html#document-schemas-features). To update a document with an older
        schema version you must recreate the resource.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        foo = aws.ssm.Document("foo",
            content=\"\"\"  {
            "schemaVersion": "1.2",
            "description": "Check ip configuration of a Linux instance.",
            "parameters": {

            },
            "runtimeConfig": {
              "aws:runShellScript": {
                "properties": [
                  {
                    "id": "0.aws:runShellScript",
                    "runCommand": ["ifconfig"]
                  }
                ]
              }
            }
          }

        \"\"\",
            document_type="Command")
        ```

        ## Permissions

        The permissions attribute specifies how you want to share the document. If you share a document privately,
        you must specify the AWS user account IDs for those people who can use the document. If you share a document
        publicly, you must specify All as the account ID.

        The permissions mapping supports the following:

        * `type` - The permission type for the document. The permission type can be `Share`.
        * `account_ids` - The AWS user accounts that should have access to the document. The account IDs can either be a group of account IDs or `All`.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] attachments_sources: One or more configuration blocks describing attachments sources to a version of a document. Defined below.
        :param pulumi.Input[str] content: The JSON or YAML content of the document.
        :param pulumi.Input[str] document_format: The format of the document. Valid document types include: `JSON` and `YAML`
        :param pulumi.Input[str] document_type: The type of the document. Valid document types include: `Automation`, `Command`, `Package`, `Policy`, and `Session`
        :param pulumi.Input[str] name: The name of the document.
        :param pulumi.Input[dict] permissions: Additional Permissions to attach to the document. See Permissions below for details.
        :param pulumi.Input[dict] tags: A map of tags to assign to the object.
        :param pulumi.Input[str] target_type: The target type which defines the kinds of resources the document can run on. For example, /AWS::EC2::Instance. For a list of valid resource types, see AWS Resource Types Reference (http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html)

        The **attachments_sources** object supports the following:

          * `key` (`pulumi.Input[str]`) - The key describing the location of an attachment to a document. Valid key types include: `SourceUrl` and `S3FileUrl`
          * `name` (`pulumi.Input[str]`) - The name of the document attachment file
          * `values` (`pulumi.Input[list]`) - The value describing the location of an attachment to a document
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['attachments_sources'] = attachments_sources
            if content is None:
                raise TypeError("Missing required property 'content'")
            __props__['content'] = content
            __props__['document_format'] = document_format
            if document_type is None:
                raise TypeError("Missing required property 'document_type'")
            __props__['document_type'] = document_type
            __props__['name'] = name
            __props__['permissions'] = permissions
            __props__['tags'] = tags
            __props__['target_type'] = target_type
            __props__['arn'] = None
            __props__['created_date'] = None
            __props__['default_version'] = None
            __props__['description'] = None
            __props__['hash'] = None
            __props__['hash_type'] = None
            __props__['latest_version'] = None
            __props__['owner'] = None
            __props__['parameters'] = None
            __props__['platform_types'] = None
            __props__['schema_version'] = None
            __props__['status'] = None
        super(Document, __self__).__init__(
            'aws:ssm/document:Document',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, attachments_sources=None, content=None, created_date=None, default_version=None, description=None, document_format=None, document_type=None, hash=None, hash_type=None, latest_version=None, name=None, owner=None, parameters=None, permissions=None, platform_types=None, schema_version=None, status=None, tags=None, target_type=None):
        """
        Get an existing Document resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] attachments_sources: One or more configuration blocks describing attachments sources to a version of a document. Defined below.
        :param pulumi.Input[str] content: The JSON or YAML content of the document.
        :param pulumi.Input[str] created_date: The date the document was created.
        :param pulumi.Input[str] default_version: The default version of the document.
        :param pulumi.Input[str] description: The description of the document.
        :param pulumi.Input[str] document_format: The format of the document. Valid document types include: `JSON` and `YAML`
        :param pulumi.Input[str] document_type: The type of the document. Valid document types include: `Automation`, `Command`, `Package`, `Policy`, and `Session`
        :param pulumi.Input[str] hash: The sha1 or sha256 of the document content
        :param pulumi.Input[str] hash_type: "Sha1" "Sha256". The hashing algorithm used when hashing the content.
        :param pulumi.Input[str] latest_version: The latest version of the document.
        :param pulumi.Input[str] name: The name of the document.
        :param pulumi.Input[str] owner: The AWS user account of the person who created the document.
        :param pulumi.Input[list] parameters: The parameters that are available to this document.
        :param pulumi.Input[dict] permissions: Additional Permissions to attach to the document. See Permissions below for details.
        :param pulumi.Input[list] platform_types: A list of OS platforms compatible with this SSM document, either "Windows" or "Linux".
        :param pulumi.Input[str] schema_version: The schema version of the document.
        :param pulumi.Input[str] status: "Creating", "Active" or "Deleting". The current status of the document.
        :param pulumi.Input[dict] tags: A map of tags to assign to the object.
        :param pulumi.Input[str] target_type: The target type which defines the kinds of resources the document can run on. For example, /AWS::EC2::Instance. For a list of valid resource types, see AWS Resource Types Reference (http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html)

        The **attachments_sources** object supports the following:

          * `key` (`pulumi.Input[str]`) - The key describing the location of an attachment to a document. Valid key types include: `SourceUrl` and `S3FileUrl`
          * `name` (`pulumi.Input[str]`) - The name of the document attachment file
          * `values` (`pulumi.Input[list]`) - The value describing the location of an attachment to a document

        The **parameters** object supports the following:

          * `default_value` (`pulumi.Input[str]`)
          * `description` (`pulumi.Input[str]`) - The description of the document.
          * `name` (`pulumi.Input[str]`) - The name of the document.
          * `type` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["attachments_sources"] = attachments_sources
        __props__["content"] = content
        __props__["created_date"] = created_date
        __props__["default_version"] = default_version
        __props__["description"] = description
        __props__["document_format"] = document_format
        __props__["document_type"] = document_type
        __props__["hash"] = hash
        __props__["hash_type"] = hash_type
        __props__["latest_version"] = latest_version
        __props__["name"] = name
        __props__["owner"] = owner
        __props__["parameters"] = parameters
        __props__["permissions"] = permissions
        __props__["platform_types"] = platform_types
        __props__["schema_version"] = schema_version
        __props__["status"] = status
        __props__["tags"] = tags
        __props__["target_type"] = target_type
        return Document(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetVpcEndpointResult:
    """
    A collection of values returned by getVpcEndpoint.
    """
    def __init__(__self__, cidr_blocks=None, dns_entries=None, filters=None, id=None, network_interface_ids=None, owner_id=None, policy=None, prefix_list_id=None, private_dns_enabled=None, requester_managed=None, route_table_ids=None, security_group_ids=None, service_name=None, state=None, subnet_ids=None, tags=None, vpc_endpoint_type=None, vpc_id=None):
        if cidr_blocks and not isinstance(cidr_blocks, list):
            raise TypeError("Expected argument 'cidr_blocks' to be a list")
        __self__.cidr_blocks = cidr_blocks
        """
        The list of CIDR blocks for the exposed AWS service. Applicable for endpoints of type `Gateway`.
        """
        if dns_entries and not isinstance(dns_entries, list):
            raise TypeError("Expected argument 'dns_entries' to be a list")
        __self__.dns_entries = dns_entries
        """
        The DNS entries for the VPC Endpoint. Applicable for endpoints of type `Interface`. DNS blocks are documented below.
        """
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        __self__.filters = filters
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        if network_interface_ids and not isinstance(network_interface_ids, list):
            raise TypeError("Expected argument 'network_interface_ids' to be a list")
        __self__.network_interface_ids = network_interface_ids
        """
        One or more network interfaces for the VPC Endpoint. Applicable for endpoints of type `Interface`.
        """
        if owner_id and not isinstance(owner_id, str):
            raise TypeError("Expected argument 'owner_id' to be a str")
        __self__.owner_id = owner_id
        """
        The ID of the AWS account that owns the VPC endpoint.
        """
        if policy and not isinstance(policy, str):
            raise TypeError("Expected argument 'policy' to be a str")
        __self__.policy = policy
        """
        The policy document associated with the VPC Endpoint. Applicable for endpoints of type `Gateway`.
        """
        if prefix_list_id and not isinstance(prefix_list_id, str):
            raise TypeError("Expected argument 'prefix_list_id' to be a str")
        __self__.prefix_list_id = prefix_list_id
        """
        The prefix list ID of the exposed AWS service. Applicable for endpoints of type `Gateway`.
        """
        if private_dns_enabled and not isinstance(private_dns_enabled, bool):
            raise TypeError("Expected argument 'private_dns_enabled' to be a bool")
        __self__.private_dns_enabled = private_dns_enabled
        """
        Whether or not the VPC is associated with a private hosted zone - `true` or `false`. Applicable for endpoints of type `Interface`.
        """
        if requester_managed and not isinstance(requester_managed, bool):
            raise TypeError("Expected argument 'requester_managed' to be a bool")
        __self__.requester_managed = requester_managed
        """
        Whether or not the VPC Endpoint is being managed by its service - `true` or `false`.
        """
        if route_table_ids and not isinstance(route_table_ids, list):
            raise TypeError("Expected argument 'route_table_ids' to be a list")
        __self__.route_table_ids = route_table_ids
        """
        One or more route tables associated with the VPC Endpoint. Applicable for endpoints of type `Gateway`.
        """
        if security_group_ids and not isinstance(security_group_ids, list):
            raise TypeError("Expected argument 'security_group_ids' to be a list")
        __self__.security_group_ids = security_group_ids
        """
        One or more security groups associated with the network interfaces. Applicable for endpoints of type `Interface`.
        """
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        __self__.service_name = service_name
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        __self__.state = state
        if subnet_ids and not isinstance(subnet_ids, list):
            raise TypeError("Expected argument 'subnet_ids' to be a list")
        __self__.subnet_ids = subnet_ids
        """
        One or more subnets in which the VPC Endpoint is located. Applicable for endpoints of type `Interface`.
        """
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        if vpc_endpoint_type and not isinstance(vpc_endpoint_type, str):
            raise TypeError("Expected argument 'vpc_endpoint_type' to be a str")
        __self__.vpc_endpoint_type = vpc_endpoint_type
        """
        The VPC Endpoint type, `Gateway` or `Interface`.
        """
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        __self__.vpc_id = vpc_id
class AwaitableGetVpcEndpointResult(GetVpcEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcEndpointResult(
            cidr_blocks=self.cidr_blocks,
            dns_entries=self.dns_entries,
            filters=self.filters,
            id=self.id,
            network_interface_ids=self.network_interface_ids,
            owner_id=self.owner_id,
            policy=self.policy,
            prefix_list_id=self.prefix_list_id,
            private_dns_enabled=self.private_dns_enabled,
            requester_managed=self.requester_managed,
            route_table_ids=self.route_table_ids,
            security_group_ids=self.security_group_ids,
            service_name=self.service_name,
            state=self.state,
            subnet_ids=self.subnet_ids,
            tags=self.tags,
            vpc_endpoint_type=self.vpc_endpoint_type,
            vpc_id=self.vpc_id)

def get_vpc_endpoint(filters=None,id=None,service_name=None,state=None,tags=None,vpc_id=None,opts=None):
    """
    The VPC Endpoint data source provides details about
    a specific VPC endpoint.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_aws as aws

    s3 = aws.ec2.get_vpc_endpoint(service_name="com.amazonaws.us-west-2.s3",
        vpc_id=aws_vpc["foo"]["id"])
    private_s3 = aws.ec2.VpcEndpointRouteTableAssociation("privateS3",
        route_table_id=aws_route_table["private"]["id"],
        vpc_endpoint_id=s3.id)
    ```



    :param list filters: Custom filter block as described below.
    :param str id: The ID of the specific VPC Endpoint to retrieve.
    :param str service_name: The service name of the specific VPC Endpoint to retrieve. For AWS services the service name is usually in the form `com.amazonaws.<region>.<service>` (the SageMaker Notebook service is an exception to this rule, the service name is in the form `aws.sagemaker.<region>.notebook`).
    :param str state: The state of the specific VPC Endpoint to retrieve.
    :param dict tags: A map of tags, each pair of which must exactly match
           a pair on the specific VPC Endpoint to retrieve.
    :param str vpc_id: The ID of the VPC in which the specific VPC Endpoint is used.

    The **filters** object supports the following:

      * `name` (`str`) - The name of the field to filter by, as defined by
        [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpoints.html).
      * `values` (`list`) - Set of values that are accepted for the given field.
        A VPC Endpoint will be selected if any one of the given values matches.
    """
    __args__ = dict()


    __args__['filters'] = filters
    __args__['id'] = id
    __args__['serviceName'] = service_name
    __args__['state'] = state
    __args__['tags'] = tags
    __args__['vpcId'] = vpc_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:ec2/getVpcEndpoint:getVpcEndpoint', __args__, opts=opts).value

    return AwaitableGetVpcEndpointResult(
        cidr_blocks=__ret__.get('cidrBlocks'),
        dns_entries=__ret__.get('dnsEntries'),
        filters=__ret__.get('filters'),
        id=__ret__.get('id'),
        network_interface_ids=__ret__.get('networkInterfaceIds'),
        owner_id=__ret__.get('ownerId'),
        policy=__ret__.get('policy'),
        prefix_list_id=__ret__.get('prefixListId'),
        private_dns_enabled=__ret__.get('privateDnsEnabled'),
        requester_managed=__ret__.get('requesterManaged'),
        route_table_ids=__ret__.get('routeTableIds'),
        security_group_ids=__ret__.get('securityGroupIds'),
        service_name=__ret__.get('serviceName'),
        state=__ret__.get('state'),
        subnet_ids=__ret__.get('subnetIds'),
        tags=__ret__.get('tags'),
        vpc_endpoint_type=__ret__.get('vpcEndpointType'),
        vpc_id=__ret__.get('vpcId'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Workgroup(pulumi.CustomResource):
    arn: pulumi.Output[str]
    """
    Amazon Resource Name (ARN) of the workgroup
    """
    configuration: pulumi.Output[dict]
    """
    Configuration block with various settings for the workgroup. Documented below.

      * `bytesScannedCutoffPerQuery` (`float`) - Integer for the upper data usage limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan. Must be at least `10485760`.
      * `enforceWorkgroupConfiguration` (`bool`) - Boolean whether the settings for the workgroup override client-side settings. For more information, see [Workgroup Settings Override Client-Side Settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html). Defaults to `true`.
      * `publishCloudwatchMetricsEnabled` (`bool`) - Boolean whether Amazon CloudWatch metrics are enabled for the workgroup. Defaults to `true`.
      * `resultConfiguration` (`dict`) - Configuration block with result settings. Documented below.
        * `encryption_configuration` (`dict`) - Configuration block with encryption settings. Documented below.
          * `encryptionOption` (`str`) - Indicates whether Amazon S3 server-side encryption with Amazon S3-managed keys (`SSE_S3`), server-side encryption with KMS-managed keys (`SSE_KMS`), or client-side encryption with KMS-managed keys (`CSE_KMS`) is used. If a query runs in a workgroup and the workgroup overrides client-side settings, then the workgroup's setting for encryption is used. It specifies whether query results must be encrypted, for all queries that run in this workgroup.
          * `kms_key_arn` (`str`) - For `SSE_KMS` and `CSE_KMS`, this is the KMS key Amazon Resource Name (ARN).

        * `output_location` (`str`) - The location in Amazon S3 where your query results are stored, such as `s3://path/to/query/bucket/`. For more information, see [Queries and Query Result Files](https://docs.aws.amazon.com/athena/latest/ug/querying.html).
    """
    description: pulumi.Output[str]
    """
    Description of the workgroup.
    """
    force_destroy: pulumi.Output[bool]
    """
    The option to delete the workgroup and its contents even if the workgroup contains any named queries.
    """
    name: pulumi.Output[str]
    """
    Name of the workgroup.
    """
    state: pulumi.Output[str]
    """
    State of the workgroup. Valid values are `DISABLED` or `ENABLED`. Defaults to `ENABLED`.
    """
    tags: pulumi.Output[dict]
    """
    Key-value map of resource tags for the workgroup.
    """
    def __init__(__self__, resource_name, opts=None, configuration=None, description=None, force_destroy=None, name=None, state=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides an Athena Workgroup.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.athena.Workgroup("example", configuration={
            "enforceWorkgroupConfiguration": True,
            "publishCloudwatchMetricsEnabled": True,
            "resultConfiguration": {
                "encryptionConfiguration": {
                    "encryptionOption": "SSE_KMS",
                    "kmsKeyArn": aws_kms_key["example"]["arn"],
                },
                "outputLocation": "s3://{aws_s3_bucket.example.bucket}/output/",
            },
        })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] configuration: Configuration block with various settings for the workgroup. Documented below.
        :param pulumi.Input[str] description: Description of the workgroup.
        :param pulumi.Input[bool] force_destroy: The option to delete the workgroup and its contents even if the workgroup contains any named queries.
        :param pulumi.Input[str] name: Name of the workgroup.
        :param pulumi.Input[str] state: State of the workgroup. Valid values are `DISABLED` or `ENABLED`. Defaults to `ENABLED`.
        :param pulumi.Input[dict] tags: Key-value map of resource tags for the workgroup.

        The **configuration** object supports the following:

          * `bytesScannedCutoffPerQuery` (`pulumi.Input[float]`) - Integer for the upper data usage limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan. Must be at least `10485760`.
          * `enforceWorkgroupConfiguration` (`pulumi.Input[bool]`) - Boolean whether the settings for the workgroup override client-side settings. For more information, see [Workgroup Settings Override Client-Side Settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html). Defaults to `true`.
          * `publishCloudwatchMetricsEnabled` (`pulumi.Input[bool]`) - Boolean whether Amazon CloudWatch metrics are enabled for the workgroup. Defaults to `true`.
          * `resultConfiguration` (`pulumi.Input[dict]`) - Configuration block with result settings. Documented below.
            * `encryption_configuration` (`pulumi.Input[dict]`) - Configuration block with encryption settings. Documented below.
              * `encryptionOption` (`pulumi.Input[str]`) - Indicates whether Amazon S3 server-side encryption with Amazon S3-managed keys (`SSE_S3`), server-side encryption with KMS-managed keys (`SSE_KMS`), or client-side encryption with KMS-managed keys (`CSE_KMS`) is used. If a query runs in a workgroup and the workgroup overrides client-side settings, then the workgroup's setting for encryption is used. It specifies whether query results must be encrypted, for all queries that run in this workgroup.
              * `kms_key_arn` (`pulumi.Input[str]`) - For `SSE_KMS` and `CSE_KMS`, this is the KMS key Amazon Resource Name (ARN).

            * `output_location` (`pulumi.Input[str]`) - The location in Amazon S3 where your query results are stored, such as `s3://path/to/query/bucket/`. For more information, see [Queries and Query Result Files](https://docs.aws.amazon.com/athena/latest/ug/querying.html).
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['configuration'] = configuration
            __props__['description'] = description
            __props__['force_destroy'] = force_destroy
            __props__['name'] = name
            __props__['state'] = state
            __props__['tags'] = tags
            __props__['arn'] = None
        super(Workgroup, __self__).__init__(
            'aws:athena/workgroup:Workgroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, configuration=None, description=None, force_destroy=None, name=None, state=None, tags=None):
        """
        Get an existing Workgroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: Amazon Resource Name (ARN) of the workgroup
        :param pulumi.Input[dict] configuration: Configuration block with various settings for the workgroup. Documented below.
        :param pulumi.Input[str] description: Description of the workgroup.
        :param pulumi.Input[bool] force_destroy: The option to delete the workgroup and its contents even if the workgroup contains any named queries.
        :param pulumi.Input[str] name: Name of the workgroup.
        :param pulumi.Input[str] state: State of the workgroup. Valid values are `DISABLED` or `ENABLED`. Defaults to `ENABLED`.
        :param pulumi.Input[dict] tags: Key-value map of resource tags for the workgroup.

        The **configuration** object supports the following:

          * `bytesScannedCutoffPerQuery` (`pulumi.Input[float]`) - Integer for the upper data usage limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan. Must be at least `10485760`.
          * `enforceWorkgroupConfiguration` (`pulumi.Input[bool]`) - Boolean whether the settings for the workgroup override client-side settings. For more information, see [Workgroup Settings Override Client-Side Settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html). Defaults to `true`.
          * `publishCloudwatchMetricsEnabled` (`pulumi.Input[bool]`) - Boolean whether Amazon CloudWatch metrics are enabled for the workgroup. Defaults to `true`.
          * `resultConfiguration` (`pulumi.Input[dict]`) - Configuration block with result settings. Documented below.
            * `encryption_configuration` (`pulumi.Input[dict]`) - Configuration block with encryption settings. Documented below.
              * `encryptionOption` (`pulumi.Input[str]`) - Indicates whether Amazon S3 server-side encryption with Amazon S3-managed keys (`SSE_S3`), server-side encryption with KMS-managed keys (`SSE_KMS`), or client-side encryption with KMS-managed keys (`CSE_KMS`) is used. If a query runs in a workgroup and the workgroup overrides client-side settings, then the workgroup's setting for encryption is used. It specifies whether query results must be encrypted, for all queries that run in this workgroup.
              * `kms_key_arn` (`pulumi.Input[str]`) - For `SSE_KMS` and `CSE_KMS`, this is the KMS key Amazon Resource Name (ARN).

            * `output_location` (`pulumi.Input[str]`) - The location in Amazon S3 where your query results are stored, such as `s3://path/to/query/bucket/`. For more information, see [Queries and Query Result Files](https://docs.aws.amazon.com/athena/latest/ug/querying.html).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["configuration"] = configuration
        __props__["description"] = description
        __props__["force_destroy"] = force_destroy
        __props__["name"] = name
        __props__["state"] = state
        __props__["tags"] = tags
        return Workgroup(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class EventRule(pulumi.CustomResource):
    arn: pulumi.Output[str]
    """
    The Amazon Resource Name (ARN) of the rule.
    """
    description: pulumi.Output[str]
    """
    The description of the rule.
    """
    event_pattern: pulumi.Output[str]
    """
    Event pattern
    described a JSON object.
    See full documentation of [CloudWatch Events and Event Patterns](http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/CloudWatchEventsandEventPatterns.html) for details.
    """
    is_enabled: pulumi.Output[bool]
    """
    Whether the rule should be enabled (defaults to `true`).
    """
    name: pulumi.Output[str]
    """
    The rule's name. By default generated by this provider.
    """
    name_prefix: pulumi.Output[str]
    """
    The rule's name. Conflicts with `name`.
    """
    role_arn: pulumi.Output[str]
    """
    The Amazon Resource Name (ARN) associated with the role that is used for target invocation.
    """
    schedule_expression: pulumi.Output[str]
    """
    The scheduling expression.
    For example, `cron(0 20 * * ? *)` or `rate(5 minutes)`.
    """
    tags: pulumi.Output[dict]
    """
    A map of tags to assign to the resource.
    """
    def __init__(__self__, resource_name, opts=None, description=None, event_pattern=None, is_enabled=None, name=None, name_prefix=None, role_arn=None, schedule_expression=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a CloudWatch Event Rule resource.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        console = aws.cloudwatch.EventRule("console",
            description="Capture each AWS Console Sign In",
            event_pattern=\"\"\"{
          "detail-type": [
            "AWS Console Sign In via CloudTrail"
          ]
        }

        \"\"\")
        aws_logins = aws.sns.Topic("awsLogins")
        sns = aws.cloudwatch.EventTarget("sns",
            arn=aws_logins.arn,
            rule=console.name)
        sns_topic_policy = aws_logins.arn.apply(lambda arn: aws.iam.get_policy_document(statements=[{
            "actions": ["SNS:Publish"],
            "effect": "Allow",
            "principals": [{
                "identifiers": ["events.amazonaws.com"],
                "type": "Service",
            }],
            "resources": [arn],
        }]))
        default = aws.sns.TopicPolicy("default",
            arn=aws_logins.arn,
            policy=sns_topic_policy.json)
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the rule.
        :param pulumi.Input[str] event_pattern: Event pattern
               described a JSON object.
               See full documentation of [CloudWatch Events and Event Patterns](http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/CloudWatchEventsandEventPatterns.html) for details.
        :param pulumi.Input[bool] is_enabled: Whether the rule should be enabled (defaults to `true`).
        :param pulumi.Input[str] name: The rule's name. By default generated by this provider.
        :param pulumi.Input[str] name_prefix: The rule's name. Conflicts with `name`.
        :param pulumi.Input[str] role_arn: The Amazon Resource Name (ARN) associated with the role that is used for target invocation.
        :param pulumi.Input[str] schedule_expression: The scheduling expression.
               For example, `cron(0 20 * * ? *)` or `rate(5 minutes)`.
        :param pulumi.Input[dict] tags: A map of tags to assign to the resource.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['description'] = description
            __props__['event_pattern'] = event_pattern
            __props__['is_enabled'] = is_enabled
            __props__['name'] = name
            __props__['name_prefix'] = name_prefix
            __props__['role_arn'] = role_arn
            __props__['schedule_expression'] = schedule_expression
            __props__['tags'] = tags
            __props__['arn'] = None
        super(EventRule, __self__).__init__(
            'aws:cloudwatch/eventRule:EventRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, description=None, event_pattern=None, is_enabled=None, name=None, name_prefix=None, role_arn=None, schedule_expression=None, tags=None):
        """
        Get an existing EventRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The Amazon Resource Name (ARN) of the rule.
        :param pulumi.Input[str] description: The description of the rule.
        :param pulumi.Input[str] event_pattern: Event pattern
               described a JSON object.
               See full documentation of [CloudWatch Events and Event Patterns](http://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/CloudWatchEventsandEventPatterns.html) for details.
        :param pulumi.Input[bool] is_enabled: Whether the rule should be enabled (defaults to `true`).
        :param pulumi.Input[str] name: The rule's name. By default generated by this provider.
        :param pulumi.Input[str] name_prefix: The rule's name. Conflicts with `name`.
        :param pulumi.Input[str] role_arn: The Amazon Resource Name (ARN) associated with the role that is used for target invocation.
        :param pulumi.Input[str] schedule_expression: The scheduling expression.
               For example, `cron(0 20 * * ? *)` or `rate(5 minutes)`.
        :param pulumi.Input[dict] tags: A map of tags to assign to the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["description"] = description
        __props__["event_pattern"] = event_pattern
        __props__["is_enabled"] = is_enabled
        __props__["name"] = name
        __props__["name_prefix"] = name_prefix
        __props__["role_arn"] = role_arn
        __props__["schedule_expression"] = schedule_expression
        __props__["tags"] = tags
        return EventRule(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Deployment(pulumi.CustomResource):
    api_id: pulumi.Output[str]
    """
    The API identifier.
    """
    auto_deployed: pulumi.Output[bool]
    """
    Whether the deployment was automatically released.
    """
    description: pulumi.Output[str]
    """
    The description for the deployment resource.
    """
    triggers: pulumi.Output[dict]
    """
    A map of arbitrary keys and values that, when changed, will trigger a redeployment.
    """
    def __init__(__self__, resource_name, opts=None, api_id=None, description=None, triggers=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an Amazon API Gateway Version 2 deployment.
        More information can be found in the [Amazon API Gateway Developer Guide](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api.html).

        > **Note:** Creating a deployment for an API requires at least one `apigatewayv2.Route` resource associated with that API. To avoid race conditions when all resources are being created together, you need to add implicit resource references via the `triggers` argument or explicit resource references using the [resource `dependsOn` meta-argument](https://www.pulumi.com/docs/intro/concepts/programming-model/#dependson).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.apigatewayv2.Deployment("example",
            api_id=aws_apigatewayv2_route["example"]["api_id"],
            description="Example deployment")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_id: The API identifier.
        :param pulumi.Input[str] description: The description for the deployment resource.
        :param pulumi.Input[dict] triggers: A map of arbitrary keys and values that, when changed, will trigger a redeployment.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if api_id is None:
                raise TypeError("Missing required property 'api_id'")
            __props__['api_id'] = api_id
            __props__['description'] = description
            __props__['triggers'] = triggers
            __props__['auto_deployed'] = None
        super(Deployment, __self__).__init__(
            'aws:apigatewayv2/deployment:Deployment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, api_id=None, auto_deployed=None, description=None, triggers=None):
        """
        Get an existing Deployment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_id: The API identifier.
        :param pulumi.Input[bool] auto_deployed: Whether the deployment was automatically released.
        :param pulumi.Input[str] description: The description for the deployment resource.
        :param pulumi.Input[dict] triggers: A map of arbitrary keys and values that, when changed, will trigger a redeployment.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["api_id"] = api_id
        __props__["auto_deployed"] = auto_deployed
        __props__["description"] = description
        __props__["triggers"] = triggers
        return Deployment(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetInstanceTypeOfferingResult:
    """
    A collection of values returned by getInstanceTypeOffering.
    """
    def __init__(__self__, filters=None, id=None, instance_type=None, location_type=None, preferred_instance_types=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        __self__.filters = filters
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        __self__.instance_type = instance_type
        """
        EC2 Instance Type.
        """
        if location_type and not isinstance(location_type, str):
            raise TypeError("Expected argument 'location_type' to be a str")
        __self__.location_type = location_type
        if preferred_instance_types and not isinstance(preferred_instance_types, list):
            raise TypeError("Expected argument 'preferred_instance_types' to be a list")
        __self__.preferred_instance_types = preferred_instance_types
class AwaitableGetInstanceTypeOfferingResult(GetInstanceTypeOfferingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceTypeOfferingResult(
            filters=self.filters,
            id=self.id,
            instance_type=self.instance_type,
            location_type=self.location_type,
            preferred_instance_types=self.preferred_instance_types)

def get_instance_type_offering(filters=None,location_type=None,preferred_instance_types=None,opts=None):
    """
    Information about single EC2 Instance Type Offering.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.ec2.get_instance_type_offering(filters=[{
            "name": "instance-type",
            "values": [
                "t1.micro",
                "t2.micro",
                "t3.micro",
            ],
        }],
        preferred_instance_types=[
            "t3.micro",
            "t2.micro",
            "t1.micro",
        ])
    ```



    :param list filters: One or more configuration blocks containing name-values filters. See the [EC2 API Reference](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceTypeOfferings.html) for supported filters. Detailed below.
    :param str location_type: Location type. Defaults to `region`. Valid values: `availability-zone`, `availability-zone-id`, and `region`.
    :param list preferred_instance_types: Ordered list of preferred EC2 Instance Types. The first match in this list will be returned. If no preferred matches are found and the original search returned more than one result, an error is returned.

    The **filters** object supports the following:

      * `name` (`str`) - Name of the filter. The `location` filter depends on the top-level `location_type` argument and if not specified, defaults to the current region.
      * `values` (`list`) - List of one or more values for the filter.
    """
    __args__ = dict()


    __args__['filters'] = filters
    __args__['locationType'] = location_type
    __args__['preferredInstanceTypes'] = preferred_instance_types
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:ec2/getInstanceTypeOffering:getInstanceTypeOffering', __args__, opts=opts).value

    return AwaitableGetInstanceTypeOfferingResult(
        filters=__ret__.get('filters'),
        id=__ret__.get('id'),
        instance_type=__ret__.get('instanceType'),
        location_type=__ret__.get('locationType'),
        preferred_instance_types=__ret__.get('preferredInstanceTypes'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetFunctionResult:
    """
    A collection of values returned by getFunction.
    """
    def __init__(__self__, arn=None, dead_letter_config=None, description=None, environment=None, function_name=None, handler=None, id=None, invoke_arn=None, kms_key_arn=None, last_modified=None, layers=None, memory_size=None, qualified_arn=None, qualifier=None, reserved_concurrent_executions=None, role=None, runtime=None, source_code_hash=None, source_code_size=None, tags=None, timeout=None, tracing_config=None, version=None, vpc_config=None):
        if arn and not isinstance(arn, str):
            raise TypeError("Expected argument 'arn' to be a str")
        __self__.arn = arn
        """
        Unqualified (no `:QUALIFIER` or `:VERSION` suffix) Amazon Resource Name (ARN) identifying your Lambda Function. See also `qualified_arn`.
        """
        if dead_letter_config and not isinstance(dead_letter_config, dict):
            raise TypeError("Expected argument 'dead_letter_config' to be a dict")
        __self__.dead_letter_config = dead_letter_config
        """
        Configure the function's *dead letter queue*.
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        Description of what your Lambda Function does.
        """
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        __self__.environment = environment
        """
        The Lambda environment's configuration settings.
        """
        if function_name and not isinstance(function_name, str):
            raise TypeError("Expected argument 'function_name' to be a str")
        __self__.function_name = function_name
        if handler and not isinstance(handler, str):
            raise TypeError("Expected argument 'handler' to be a str")
        __self__.handler = handler
        """
        The function entrypoint in your code.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if invoke_arn and not isinstance(invoke_arn, str):
            raise TypeError("Expected argument 'invoke_arn' to be a str")
        __self__.invoke_arn = invoke_arn
        """
        The ARN to be used for invoking Lambda Function from API Gateway.
        """
        if kms_key_arn and not isinstance(kms_key_arn, str):
            raise TypeError("Expected argument 'kms_key_arn' to be a str")
        __self__.kms_key_arn = kms_key_arn
        """
        The ARN for the KMS encryption key.
        """
        if last_modified and not isinstance(last_modified, str):
            raise TypeError("Expected argument 'last_modified' to be a str")
        __self__.last_modified = last_modified
        """
        The date this resource was last modified.
        """
        if layers and not isinstance(layers, list):
            raise TypeError("Expected argument 'layers' to be a list")
        __self__.layers = layers
        """
        A list of Lambda Layer ARNs attached to your Lambda Function.
        """
        if memory_size and not isinstance(memory_size, float):
            raise TypeError("Expected argument 'memory_size' to be a float")
        __self__.memory_size = memory_size
        """
        Amount of memory in MB your Lambda Function can use at runtime.
        """
        if qualified_arn and not isinstance(qualified_arn, str):
            raise TypeError("Expected argument 'qualified_arn' to be a str")
        __self__.qualified_arn = qualified_arn
        """
        Qualified (`:QUALIFIER` or `:VERSION` suffix) Amazon Resource Name (ARN) identifying your Lambda Function. See also `arn`.
        """
        if qualifier and not isinstance(qualifier, str):
            raise TypeError("Expected argument 'qualifier' to be a str")
        __self__.qualifier = qualifier
        if reserved_concurrent_executions and not isinstance(reserved_concurrent_executions, float):
            raise TypeError("Expected argument 'reserved_concurrent_executions' to be a float")
        __self__.reserved_concurrent_executions = reserved_concurrent_executions
        """
        The amount of reserved concurrent executions for this lambda function or `-1` if unreserved.
        """
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        __self__.role = role
        """
        IAM role attached to the Lambda Function.
        """
        if runtime and not isinstance(runtime, str):
            raise TypeError("Expected argument 'runtime' to be a str")
        __self__.runtime = runtime
        """
        The runtime environment for the Lambda function..
        """
        if source_code_hash and not isinstance(source_code_hash, str):
            raise TypeError("Expected argument 'source_code_hash' to be a str")
        __self__.source_code_hash = source_code_hash
        """
        Base64-encoded representation of raw SHA-256 sum of the zip file.
        """
        if source_code_size and not isinstance(source_code_size, float):
            raise TypeError("Expected argument 'source_code_size' to be a float")
        __self__.source_code_size = source_code_size
        """
        The size in bytes of the function .zip file.
        """
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        if timeout and not isinstance(timeout, float):
            raise TypeError("Expected argument 'timeout' to be a float")
        __self__.timeout = timeout
        """
        The function execution time at which Lambda should terminate the function.
        """
        if tracing_config and not isinstance(tracing_config, dict):
            raise TypeError("Expected argument 'tracing_config' to be a dict")
        __self__.tracing_config = tracing_config
        """
        Tracing settings of the function.
        """
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        __self__.version = version
        """
        The version of the Lambda function.
        """
        if vpc_config and not isinstance(vpc_config, dict):
            raise TypeError("Expected argument 'vpc_config' to be a dict")
        __self__.vpc_config = vpc_config
        """
        VPC configuration associated with your Lambda function.
        """
class AwaitableGetFunctionResult(GetFunctionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFunctionResult(
            arn=self.arn,
            dead_letter_config=self.dead_letter_config,
            description=self.description,
            environment=self.environment,
            function_name=self.function_name,
            handler=self.handler,
            id=self.id,
            invoke_arn=self.invoke_arn,
            kms_key_arn=self.kms_key_arn,
            last_modified=self.last_modified,
            layers=self.layers,
            memory_size=self.memory_size,
            qualified_arn=self.qualified_arn,
            qualifier=self.qualifier,
            reserved_concurrent_executions=self.reserved_concurrent_executions,
            role=self.role,
            runtime=self.runtime,
            source_code_hash=self.source_code_hash,
            source_code_size=self.source_code_size,
            tags=self.tags,
            timeout=self.timeout,
            tracing_config=self.tracing_config,
            version=self.version,
            vpc_config=self.vpc_config)

def get_function(function_name=None,qualifier=None,tags=None,opts=None):
    """
    Provides information about a Lambda Function.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_aws as aws

    config = pulumi.Config()
    function_name = config.require_object("functionName")
    existing = aws.lambda.get_function(function_name=function_name)
    ```



    :param str function_name: Name of the lambda function.
    :param str qualifier: Alias name or version number of the lambda function. e.g. `$LATEST`, `my-alias`, or `1`
    """
    __args__ = dict()


    __args__['functionName'] = function_name
    __args__['qualifier'] = qualifier
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:lambda/getFunction:getFunction', __args__, opts=opts).value

    return AwaitableGetFunctionResult(
        arn=__ret__.get('arn'),
        dead_letter_config=__ret__.get('deadLetterConfig'),
        description=__ret__.get('description'),
        environment=__ret__.get('environment'),
        function_name=__ret__.get('functionName'),
        handler=__ret__.get('handler'),
        id=__ret__.get('id'),
        invoke_arn=__ret__.get('invokeArn'),
        kms_key_arn=__ret__.get('kmsKeyArn'),
        last_modified=__ret__.get('lastModified'),
        layers=__ret__.get('layers'),
        memory_size=__ret__.get('memorySize'),
        qualified_arn=__ret__.get('qualifiedArn'),
        qualifier=__ret__.get('qualifier'),
        reserved_concurrent_executions=__ret__.get('reservedConcurrentExecutions'),
        role=__ret__.get('role'),
        runtime=__ret__.get('runtime'),
        source_code_hash=__ret__.get('sourceCodeHash'),
        source_code_size=__ret__.get('sourceCodeSize'),
        tags=__ret__.get('tags'),
        timeout=__ret__.get('timeout'),
        tracing_config=__ret__.get('tracingConfig'),
        version=__ret__.get('version'),
        vpc_config=__ret__.get('vpcConfig'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('aws')

access_key = __config__.get('accessKey')
"""
The access key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
"""

allowed_account_ids = __config__.get('allowedAccountIds')

assume_role = __config__.get('assumeRole')

endpoints = __config__.get('endpoints')

forbidden_account_ids = __config__.get('forbiddenAccountIds')

ignore_tags = __config__.get('ignoreTags')
"""
Configuration block with settings to ignore resource tags across all resources.
"""

insecure = __config__.get('insecure')
"""
Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is `false`
"""

max_retries = __config__.get('maxRetries')
"""
The maximum number of times an AWS API request is being executed. If the API request still fails, an error is thrown.
"""

profile = __config__.get('profile') or utilities.get_env('AWS_PROFILE')
"""
The profile for API operations. If not set, the default profile created with `aws configure` will be used.
"""

region = __config__.get('region') or utilities.get_env('AWS_REGION', 'AWS_DEFAULT_REGION')
"""
The region where AWS operations will take place. Examples are us-east-1, us-west-2, etc.
"""

s3_force_path_style = __config__.get('s3ForcePathStyle')
"""
Set this to true to force the request to use path-style addressing, i.e., http://s3.amazonaws.com/BUCKET/KEY. By
default, the S3 client will use virtual hosted bucket addressing when possible (http://BUCKET.s3.amazonaws.com/KEY).
Specific to the Amazon S3 service.
"""

secret_key = __config__.get('secretKey')
"""
The secret key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
"""

shared_credentials_file = __config__.get('sharedCredentialsFile')
"""
The path to the shared credentials file. If not set this defaults to ~/.aws/credentials.
"""

skip_credentials_validation = __config__.get('skipCredentialsValidation')
"""
Skip the credentials validation via STS API. Used for AWS API implementations that do not have STS
available/implemented.
"""

skip_get_ec2_platforms = __config__.get('skipGetEc2Platforms')
"""
Skip getting the supported EC2 platforms. Used by users that don't have ec2:DescribeAccountAttributes permissions.
"""

skip_metadata_api_check = __config__.get('skipMetadataApiCheck')

skip_region_validation = __config__.get('skipRegionValidation')
"""
Skip static validation of region name. Used by users of alternative AWS-like APIs or users w/ access to regions that are
not public (yet).
"""

skip_requesting_account_id = __config__.get('skipRequestingAccountId')
"""
Skip requesting the account ID. Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
"""

token = __config__.get('token')
"""
session token. A session token is only required if you are using temporary security credentials.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class AnalyticsApplication(pulumi.CustomResource):
    arn: pulumi.Output[str]
    """
    The ARN of the Kinesis Analytics Appliation.
    """
    cloudwatch_logging_options: pulumi.Output[dict]
    """
    The CloudWatch log stream options to monitor application errors.
    See CloudWatch Logging Options below for more details.

      * `id` (`str`) - The ARN of the Kinesis Analytics Application.
      * `logStreamArn` (`str`) - The ARN of the CloudWatch Log Stream.
      * `role_arn` (`str`) - The ARN of the IAM Role used to send application messages.
    """
    code: pulumi.Output[str]
    """
    SQL Code to transform input data, and generate output.
    """
    create_timestamp: pulumi.Output[str]
    """
    The Timestamp when the application version was created.
    """
    description: pulumi.Output[str]
    """
    Description of the application.
    """
    inputs: pulumi.Output[dict]
    """
    Input configuration of the application. See Inputs below for more details.

      * `id` (`str`) - The ARN of the Kinesis Analytics Application.
      * `kinesisFirehose` (`dict`) - The Kinesis Firehose configuration for the streaming source. Conflicts with `kinesis_stream`.
        See Kinesis Firehose below for more details.
        * `resource_arn` (`str`) - The ARN of the Kinesis Firehose delivery stream.
        * `role_arn` (`str`) - The ARN of the IAM Role used to access the stream.

      * `kinesisStream` (`dict`) - The Kinesis Stream configuration for the streaming source. Conflicts with `kinesis_firehose`.
        See Kinesis Stream below for more details.
        * `resource_arn` (`str`) - The ARN of the Kinesis Stream.
        * `role_arn` (`str`) - The ARN of the IAM Role used to access the stream.

      * `name_prefix` (`str`) - The Name Prefix to use when creating an in-application stream.
      * `parallelism` (`dict`) - The number of Parallel in-application streams to create.
        See Parallelism below for more details.
        * `count` (`float`) - The Count of streams.

      * `processingConfiguration` (`dict`) - The Processing Configuration to transform records as they are received from the stream.
        See Processing Configuration below for more details.
        * `lambda_` (`dict`) - The Lambda function configuration. See Lambda below for more details.
          * `resource_arn` (`str`) - The ARN of the Lambda function.
          * `role_arn` (`str`) - The ARN of the IAM Role used to access the Lambda function.

      * `schema` (`dict`) - The Schema format of the data in the streaming source. See Source Schema below for more details.
        * `recordColumns` (`list`) - The Record Column mapping for the streaming source data element.
          See Record Columns below for more details.
          * `mapping` (`str`) - The Mapping reference to the data element.
          * `name` (`str`) - Name of the column.
          * `sqlType` (`str`) - The SQL Type of the column.

        * `recordEncoding` (`str`) - The Encoding of the record in the streaming source.
        * `recordFormat` (`dict`) - The Record Format and mapping information to schematize a record.
          See Record Format below for more details.
          * `mappingParameters` (`dict`) - The Mapping Information for the record format.
            See Mapping Parameters below for more details.
            * `csv` (`dict`) - Mapping information when the record format uses delimiters.
              See CSV Mapping Parameters below for more details.
              * `recordColumnDelimiter` (`str`) - The Column Delimiter.
              * `recordRowDelimiter` (`str`) - The Row Delimiter.

            * `json` (`dict`) - Mapping information when JSON is the record format on the streaming source.
              See JSON Mapping Parameters below for more details.
              * `recordRowPath` (`str`) - Path to the top-level parent that contains the records.

          * `recordFormatType` (`str`) - The type of Record Format. Can be `CSV` or `JSON`.

      * `startingPositionConfigurations` (`list`)
        * `starting_position` (`str`)

      * `streamNames` (`list`)
    """
    last_update_timestamp: pulumi.Output[str]
    """
    The Timestamp when the application was last updated.
    """
    name: pulumi.Output[str]
    """
    Name of the Kinesis Analytics Application.
    """
    outputs: pulumi.Output[list]
    """
    Output destination configuration of the application. See Outputs below for more details.

      * `id` (`str`) - The ARN of the Kinesis Analytics Application.
      * `kinesisFirehose` (`dict`) - The Kinesis Firehose configuration for the destination stream. Conflicts with `kinesis_stream`.
        See Kinesis Firehose below for more details.
        * `resource_arn` (`str`) - The ARN of the Kinesis Firehose delivery stream.
        * `role_arn` (`str`) - The ARN of the IAM Role used to access the stream.

      * `kinesisStream` (`dict`) - The Kinesis Stream configuration for the destination stream. Conflicts with `kinesis_firehose`.
        See Kinesis Stream below for more details.
        * `resource_arn` (`str`) - The ARN of the Kinesis Stream.
        * `role_arn` (`str`) - The ARN of the IAM Role used to access the stream.

      * `lambda_` (`dict`) - The Lambda function destination. See Lambda below for more details.
        * `resource_arn` (`str`) - The ARN of the Lambda function.
        * `role_arn` (`str`) - The ARN of the IAM Role used to access the Lambda function.

      * `name` (`str`) - The Name of the in-application stream.
      * `schema` (`dict`) - The Schema format of the data written to the destination. See Destination Schema below for more details.
        * `recordFormatType` (`str`) - The Format Type of the records on the output stream. Can be `CSV` or `JSON`.
    """
    reference_data_sources: pulumi.Output[dict]
    """
    An S3 Reference Data Source for the application.
    See Reference Data Sources below for more details.

      * `id` (`str`) - The ARN of the Kinesis Analytics Application.
      * `s3` (`dict`) - The S3 configuration for the reference data source. See S3 Reference below for more details.
        * `bucketArn` (`str`) - The S3 Bucket ARN.
        * `fileKey` (`str`) - The File Key name containing reference data.
        * `role_arn` (`str`) - The ARN of the IAM Role used to send application messages.

      * `schema` (`dict`) - The Schema format of the data in the streaming source. See Source Schema below for more details.
        * `recordColumns` (`list`) - The Record Column mapping for the streaming source data element.
          See Record Columns below for more details.
          * `mapping` (`str`) - The Mapping reference to the data element.
          * `name` (`str`) - Name of the column.
          * `sqlType` (`str`) - The SQL Type of the column.

        * `recordEncoding` (`str`) - The Encoding of the record in the streaming source.
        * `recordFormat` (`dict`) - The Record Format and mapping information to schematize a record.
          See Record Format below for more details.
          * `mappingParameters` (`dict`) - The Mapping Information for the record format.
            See Mapping Parameters below for more details.
            * `csv` (`dict`) - Mapping information when the record format uses delimiters.
              See CSV Mapping Parameters below for more details.
              * `recordColumnDelimiter` (`str`) - The Column Delimiter.
              * `recordRowDelimiter` (`str`) - The Row Delimiter.

            * `json` (`dict`) - Mapping information when JSON is the record format on the streaming source.
              See JSON Mapping Parameters below for more details.
              * `recordRowPath` (`str`) - Path to the top-level parent that contains the records.

          * `recordFormatType` (`str`) - The type of Record Format. Can be `CSV` or `JSON`.

      * `table_name` (`str`) - The in-application Table Name.
    """
    status: pulumi.Output[str]
    """
    The Status of the application.
    """
    tags: pulumi.Output[dict]
    """
    Key-value map of tags for the Kinesis Analytics Application.
    """
    version: pulumi.Output[float]
    """
    The Version of the application.
    """
    def __init__(__self__, resource_name, opts=None, cloudwatch_logging_options=None, code=None, description=None, inputs=None, name=None, outputs=None, reference_data_sources=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Kinesis Analytics Application resource. Kinesis Analytics is a managed service that
        allows processing and analyzing streaming data using standard SQL.

        For more details, see the [Amazon Kinesis Analytics Documentation](https://docs.aws.amazon.com/kinesisanalytics/latest/dev/what-is.html).

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        test_stream = aws.kinesis.Stream("testStream", shard_count=1)
        test_application = aws.kinesis.AnalyticsApplication("testApplication", inputs={
            "kinesisStream": {
                "resourceArn": test_stream.arn,
                "roleArn": aws_iam_role["test"]["arn"],
            },
            "namePrefix": "test_prefix",
            "parallelism": {
                "count": 1,
            },
            "schema": {
                "recordColumns": [{
                    "mapping": "$$.test",
                    "name": "test",
                    "sqlType": "VARCHAR(8)",
                }],
                "recordEncoding": "UTF-8",
                "recordFormat": {
                    "mappingParameters": {
                        "json": {
                            "recordRowPath": "$$",
                        },
                    },
                },
            },
        })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] cloudwatch_logging_options: The CloudWatch log stream options to monitor application errors.
               See CloudWatch Logging Options below for more details.
        :param pulumi.Input[str] code: SQL Code to transform input data, and generate output.
        :param pulumi.Input[str] description: Description of the application.
        :param pulumi.Input[dict] inputs: Input configuration of the application. See Inputs below for more details.
        :param pulumi.Input[str] name: Name of the Kinesis Analytics Application.
        :param pulumi.Input[list] outputs: Output destination configuration of the application. See Outputs below for more details.
        :param pulumi.Input[dict] reference_data_sources: An S3 Reference Data Source for the application.
               See Reference Data Sources below for more details.
        :param pulumi.Input[dict] tags: Key-value map of tags for the Kinesis Analytics Application.

        The **cloudwatch_logging_options** object supports the following:

          * `id` (`pulumi.Input[str]`) - The ARN of the Kinesis Analytics Application.
          * `logStreamArn` (`pulumi.Input[str]`) - The ARN of the CloudWatch Log Stream.
          * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to send application messages.

        The **inputs** object supports the following:

          * `id` (`pulumi.Input[str]`) - The ARN of the Kinesis Analytics Application.
          * `kinesisFirehose` (`pulumi.Input[dict]`) - The Kinesis Firehose configuration for the streaming source. Conflicts with `kinesis_stream`.
            See Kinesis Firehose below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Kinesis Firehose delivery stream.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the stream.

          * `kinesisStream` (`pulumi.Input[dict]`) - The Kinesis Stream configuration for the streaming source. Conflicts with `kinesis_firehose`.
            See Kinesis Stream below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Kinesis Stream.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the stream.

          * `name_prefix` (`pulumi.Input[str]`) - The Name Prefix to use when creating an in-application stream.
          * `parallelism` (`pulumi.Input[dict]`) - The number of Parallel in-application streams to create.
            See Parallelism below for more details.
            * `count` (`pulumi.Input[float]`) - The Count of streams.

          * `processingConfiguration` (`pulumi.Input[dict]`) - The Processing Configuration to transform records as they are received from the stream.
            See Processing Configuration below for more details.
            * `lambda_` (`pulumi.Input[dict]`) - The Lambda function configuration. See Lambda below for more details.
              * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Lambda function.
              * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the Lambda function.

          * `schema` (`pulumi.Input[dict]`) - The Schema format of the data in the streaming source. See Source Schema below for more details.
            * `recordColumns` (`pulumi.Input[list]`) - The Record Column mapping for the streaming source data element.
              See Record Columns below for more details.
              * `mapping` (`pulumi.Input[str]`) - The Mapping reference to the data element.
              * `name` (`pulumi.Input[str]`) - Name of the column.
              * `sqlType` (`pulumi.Input[str]`) - The SQL Type of the column.

            * `recordEncoding` (`pulumi.Input[str]`) - The Encoding of the record in the streaming source.
            * `recordFormat` (`pulumi.Input[dict]`) - The Record Format and mapping information to schematize a record.
              See Record Format below for more details.
              * `mappingParameters` (`pulumi.Input[dict]`) - The Mapping Information for the record format.
                See Mapping Parameters below for more details.
                * `csv` (`pulumi.Input[dict]`) - Mapping information when the record format uses delimiters.
                  See CSV Mapping Parameters below for more details.
                  * `recordColumnDelimiter` (`pulumi.Input[str]`) - The Column Delimiter.
                  * `recordRowDelimiter` (`pulumi.Input[str]`) - The Row Delimiter.

                * `json` (`pulumi.Input[dict]`) - Mapping information when JSON is the record format on the streaming source.
                  See JSON Mapping Parameters below for more details.
                  * `recordRowPath` (`pulumi.Input[str]`) - Path to the top-level parent that contains the records.

              * `recordFormatType` (`pulumi.Input[str]`) - The type of Record Format. Can be `CSV` or `JSON`.

          * `startingPositionConfigurations` (`pulumi.Input[list]`)
            * `starting_position` (`pulumi.Input[str]`)

          * `streamNames` (`pulumi.Input[list]`)

        The **outputs** object supports the following:

          * `id` (`pulumi.Input[str]`) - The ARN of the Kinesis Analytics Application.
          * `kinesisFirehose` (`pulumi.Input[dict]`) - The Kinesis Firehose configuration for the destination stream. Conflicts with `kinesis_stream`.
            See Kinesis Firehose below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Kinesis Firehose delivery stream.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the stream.

          * `kinesisStream` (`pulumi.Input[dict]`) - The Kinesis Stream configuration for the destination stream. Conflicts with `kinesis_firehose`.
            See Kinesis Stream below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Kinesis Stream.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the stream.

          * `lambda_` (`pulumi.Input[dict]`) - The Lambda function destination. See Lambda below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Lambda function.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the Lambda function.

          * `name` (`pulumi.Input[str]`) - The Name of the in-application stream.
          * `schema` (`pulumi.Input[dict]`) - The Schema format of the data written to the destination. See Destination Schema below for more details.
            * `recordFormatType` (`pulumi.Input[str]`) - The Format Type of the records on the output stream. Can be `CSV` or `JSON`.

        The **reference_data_sources** object supports the following:

          * `id` (`pulumi.Input[str]`) - The ARN of the Kinesis Analytics Application.
          * `s3` (`pulumi.Input[dict]`) - The S3 configuration for the reference data source. See S3 Reference below for more details.
            * `bucketArn` (`pulumi.Input[str]`) - The S3 Bucket ARN.
            * `fileKey` (`pulumi.Input[str]`) - The File Key name containing reference data.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to send application messages.

          * `schema` (`pulumi.Input[dict]`) - The Schema format of the data in the streaming source. See Source Schema below for more details.
            * `recordColumns` (`pulumi.Input[list]`) - The Record Column mapping for the streaming source data element.
              See Record Columns below for more details.
              * `mapping` (`pulumi.Input[str]`) - The Mapping reference to the data element.
              * `name` (`pulumi.Input[str]`) - Name of the column.
              * `sqlType` (`pulumi.Input[str]`) - The SQL Type of the column.

            * `recordEncoding` (`pulumi.Input[str]`) - The Encoding of the record in the streaming source.
            * `recordFormat` (`pulumi.Input[dict]`) - The Record Format and mapping information to schematize a record.
              See Record Format below for more details.
              * `mappingParameters` (`pulumi.Input[dict]`) - The Mapping Information for the record format.
                See Mapping Parameters below for more details.
                * `csv` (`pulumi.Input[dict]`) - Mapping information when the record format uses delimiters.
                  See CSV Mapping Parameters below for more details.
                  * `recordColumnDelimiter` (`pulumi.Input[str]`) - The Column Delimiter.
                  * `recordRowDelimiter` (`pulumi.Input[str]`) - The Row Delimiter.

                * `json` (`pulumi.Input[dict]`) - Mapping information when JSON is the record format on the streaming source.
                  See JSON Mapping Parameters below for more details.
                  * `recordRowPath` (`pulumi.Input[str]`) - Path to the top-level parent that contains the records.

              * `recordFormatType` (`pulumi.Input[str]`) - The type of Record Format. Can be `CSV` or `JSON`.

          * `table_name` (`pulumi.Input[str]`) - The in-application Table Name.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['cloudwatch_logging_options'] = cloudwatch_logging_options
            __props__['code'] = code
            __props__['description'] = description
            __props__['inputs'] = inputs
            __props__['name'] = name
            __props__['outputs'] = outputs
            __props__['reference_data_sources'] = reference_data_sources
            __props__['tags'] = tags
            __props__['arn'] = None
            __props__['create_timestamp'] = None
            __props__['last_update_timestamp'] = None
            __props__['status'] = None
            __props__['version'] = None
        super(AnalyticsApplication, __self__).__init__(
            'aws:kinesis/analyticsApplication:AnalyticsApplication',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, cloudwatch_logging_options=None, code=None, create_timestamp=None, description=None, inputs=None, last_update_timestamp=None, name=None, outputs=None, reference_data_sources=None, status=None, tags=None, version=None):
        """
        Get an existing AnalyticsApplication resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The ARN of the Kinesis Analytics Appliation.
        :param pulumi.Input[dict] cloudwatch_logging_options: The CloudWatch log stream options to monitor application errors.
               See CloudWatch Logging Options below for more details.
        :param pulumi.Input[str] code: SQL Code to transform input data, and generate output.
        :param pulumi.Input[str] create_timestamp: The Timestamp when the application version was created.
        :param pulumi.Input[str] description: Description of the application.
        :param pulumi.Input[dict] inputs: Input configuration of the application. See Inputs below for more details.
        :param pulumi.Input[str] last_update_timestamp: The Timestamp when the application was last updated.
        :param pulumi.Input[str] name: Name of the Kinesis Analytics Application.
        :param pulumi.Input[list] outputs: Output destination configuration of the application. See Outputs below for more details.
        :param pulumi.Input[dict] reference_data_sources: An S3 Reference Data Source for the application.
               See Reference Data Sources below for more details.
        :param pulumi.Input[str] status: The Status of the application.
        :param pulumi.Input[dict] tags: Key-value map of tags for the Kinesis Analytics Application.
        :param pulumi.Input[float] version: The Version of the application.

        The **cloudwatch_logging_options** object supports the following:

          * `id` (`pulumi.Input[str]`) - The ARN of the Kinesis Analytics Application.
          * `logStreamArn` (`pulumi.Input[str]`) - The ARN of the CloudWatch Log Stream.
          * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to send application messages.

        The **inputs** object supports the following:

          * `id` (`pulumi.Input[str]`) - The ARN of the Kinesis Analytics Application.
          * `kinesisFirehose` (`pulumi.Input[dict]`) - The Kinesis Firehose configuration for the streaming source. Conflicts with `kinesis_stream`.
            See Kinesis Firehose below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Kinesis Firehose delivery stream.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the stream.

          * `kinesisStream` (`pulumi.Input[dict]`) - The Kinesis Stream configuration for the streaming source. Conflicts with `kinesis_firehose`.
            See Kinesis Stream below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Kinesis Stream.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the stream.

          * `name_prefix` (`pulumi.Input[str]`) - The Name Prefix to use when creating an in-application stream.
          * `parallelism` (`pulumi.Input[dict]`) - The number of Parallel in-application streams to create.
            See Parallelism below for more details.
            * `count` (`pulumi.Input[float]`) - The Count of streams.

          * `processingConfiguration` (`pulumi.Input[dict]`) - The Processing Configuration to transform records as they are received from the stream.
            See Processing Configuration below for more details.
            * `lambda_` (`pulumi.Input[dict]`) - The Lambda function configuration. See Lambda below for more details.
              * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Lambda function.
              * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the Lambda function.

          * `schema` (`pulumi.Input[dict]`) - The Schema format of the data in the streaming source. See Source Schema below for more details.
            * `recordColumns` (`pulumi.Input[list]`) - The Record Column mapping for the streaming source data element.
              See Record Columns below for more details.
              * `mapping` (`pulumi.Input[str]`) - The Mapping reference to the data element.
              * `name` (`pulumi.Input[str]`) - Name of the column.
              * `sqlType` (`pulumi.Input[str]`) - The SQL Type of the column.

            * `recordEncoding` (`pulumi.Input[str]`) - The Encoding of the record in the streaming source.
            * `recordFormat` (`pulumi.Input[dict]`) - The Record Format and mapping information to schematize a record.
              See Record Format below for more details.
              * `mappingParameters` (`pulumi.Input[dict]`) - The Mapping Information for the record format.
                See Mapping Parameters below for more details.
                * `csv` (`pulumi.Input[dict]`) - Mapping information when the record format uses delimiters.
                  See CSV Mapping Parameters below for more details.
                  * `recordColumnDelimiter` (`pulumi.Input[str]`) - The Column Delimiter.
                  * `recordRowDelimiter` (`pulumi.Input[str]`) - The Row Delimiter.

                * `json` (`pulumi.Input[dict]`) - Mapping information when JSON is the record format on the streaming source.
                  See JSON Mapping Parameters below for more details.
                  * `recordRowPath` (`pulumi.Input[str]`) - Path to the top-level parent that contains the records.

              * `recordFormatType` (`pulumi.Input[str]`) - The type of Record Format. Can be `CSV` or `JSON`.

          * `startingPositionConfigurations` (`pulumi.Input[list]`)
            * `starting_position` (`pulumi.Input[str]`)

          * `streamNames` (`pulumi.Input[list]`)

        The **outputs** object supports the following:

          * `id` (`pulumi.Input[str]`) - The ARN of the Kinesis Analytics Application.
          * `kinesisFirehose` (`pulumi.Input[dict]`) - The Kinesis Firehose configuration for the destination stream. Conflicts with `kinesis_stream`.
            See Kinesis Firehose below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Kinesis Firehose delivery stream.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the stream.

          * `kinesisStream` (`pulumi.Input[dict]`) - The Kinesis Stream configuration for the destination stream. Conflicts with `kinesis_firehose`.
            See Kinesis Stream below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Kinesis Stream.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the stream.

          * `lambda_` (`pulumi.Input[dict]`) - The Lambda function destination. See Lambda below for more details.
            * `resource_arn` (`pulumi.Input[str]`) - The ARN of the Lambda function.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to access the Lambda function.

          * `name` (`pulumi.Input[str]`) - The Name of the in-application stream.
          * `schema` (`pulumi.Input[dict]`) - The Schema format of the data written to the destination. See Destination Schema below for more details.
            * `recordFormatType` (`pulumi.Input[str]`) - The Format Type of the records on the output stream. Can be `CSV` or `JSON`.

        The **reference_data_sources** object supports the following:

          * `id` (`pulumi.Input[str]`) - The ARN of the Kinesis Analytics Application.
          * `s3` (`pulumi.Input[dict]`) - The S3 configuration for the reference data source. See S3 Reference below for more details.
            * `bucketArn` (`pulumi.Input[str]`) - The S3 Bucket ARN.
            * `fileKey` (`pulumi.Input[str]`) - The File Key name containing reference data.
            * `role_arn` (`pulumi.Input[str]`) - The ARN of the IAM Role used to send application messages.

          * `schema` (`pulumi.Input[dict]`) - The Schema format of the data in the streaming source. See Source Schema below for more details.
            * `recordColumns` (`pulumi.Input[list]`) - The Record Column mapping for the streaming source data element.
              See Record Columns below for more details.
              * `mapping` (`pulumi.Input[str]`) - The Mapping reference to the data element.
              * `name` (`pulumi.Input[str]`) - Name of the column.
              * `sqlType` (`pulumi.Input[str]`) - The SQL Type of the column.

            * `recordEncoding` (`pulumi.Input[str]`) - The Encoding of the record in the streaming source.
            * `recordFormat` (`pulumi.Input[dict]`) - The Record Format and mapping information to schematize a record.
              See Record Format below for more details.
              * `mappingParameters` (`pulumi.Input[dict]`) - The Mapping Information for the record format.
                See Mapping Parameters below for more details.
                * `csv` (`pulumi.Input[dict]`) - Mapping information when the record format uses delimiters.
                  See CSV Mapping Parameters below for more details.
                  * `recordColumnDelimiter` (`pulumi.Input[str]`) - The Column Delimiter.
                  * `recordRowDelimiter` (`pulumi.Input[str]`) - The Row Delimiter.

                * `json` (`pulumi.Input[dict]`) - Mapping information when JSON is the record format on the streaming source.
                  See JSON Mapping Parameters below for more details.
                  * `recordRowPath` (`pulumi.Input[str]`) - Path to the top-level parent that contains the records.

              * `recordFormatType` (`pulumi.Input[str]`) - The type of Record Format. Can be `CSV` or `JSON`.

          * `table_name` (`pulumi.Input[str]`) - The in-application Table Name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["cloudwatch_logging_options"] = cloudwatch_logging_options
        __props__["code"] = code
        __props__["create_timestamp"] = create_timestamp
        __props__["description"] = description
        __props__["inputs"] = inputs
        __props__["last_update_timestamp"] = last_update_timestamp
        __props__["name"] = name
        __props__["outputs"] = outputs
        __props__["reference_data_sources"] = reference_data_sources
        __props__["status"] = status
        __props__["tags"] = tags
        __props__["version"] = version
        return AnalyticsApplication(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetCustomerGatewayResult:
    """
    A collection of values returned by getCustomerGateway.
    """
    def __init__(__self__, bgp_asn=None, filters=None, id=None, ip_address=None, tags=None, type=None):
        if bgp_asn and not isinstance(bgp_asn, float):
            raise TypeError("Expected argument 'bgp_asn' to be a float")
        __self__.bgp_asn = bgp_asn
        """
        (Optional) The gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).
        """
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        __self__.filters = filters
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        if ip_address and not isinstance(ip_address, str):
            raise TypeError("Expected argument 'ip_address' to be a str")
        __self__.ip_address = ip_address
        """
        (Optional) The IP address of the gateway's Internet-routable external interface.
        """
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        """
        Map of key-value pairs assigned to the gateway.
        """
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        __self__.type = type
        """
        (Optional) The type of customer gateway. The only type AWS supports at this time is "ipsec.1".
        """
class AwaitableGetCustomerGatewayResult(GetCustomerGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCustomerGatewayResult(
            bgp_asn=self.bgp_asn,
            filters=self.filters,
            id=self.id,
            ip_address=self.ip_address,
            tags=self.tags,
            type=self.type)

def get_customer_gateway(filters=None,id=None,tags=None,opts=None):
    """
    Get an existing AWS Customer Gateway.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_aws as aws

    foo = aws.ec2.get_customer_gateway(filters=[{
        "name": "tag:Name",
        "values": ["foo-prod"],
    }])
    main = aws.ec2.VpnGateway("main",
        amazon_side_asn=7224,
        vpc_id=aws_vpc["main"]["id"])
    transit = aws.ec2.VpnConnection("transit",
        customer_gateway_id=foo.id,
        static_routes_only=False,
        type=foo.type,
        vpn_gateway_id=main.id)
    ```



    :param list filters: One or more [name-value pairs][dcg-filters] to filter by.
    :param str id: The ID of the gateway.
    :param dict tags: Map of key-value pairs assigned to the gateway.

    The **filters** object supports the following:

      * `name` (`str`)
      * `values` (`list`)
    """
    __args__ = dict()


    __args__['filters'] = filters
    __args__['id'] = id
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:ec2/getCustomerGateway:getCustomerGateway', __args__, opts=opts).value

    return AwaitableGetCustomerGatewayResult(
        bgp_asn=__ret__.get('bgpAsn'),
        filters=__ret__.get('filters'),
        id=__ret__.get('id'),
        ip_address=__ret__.get('ipAddress'),
        tags=__ret__.get('tags'),
        type=__ret__.get('type'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class LifecyclePolicy(pulumi.CustomResource):
    policy: pulumi.Output[str]
    """
    The policy document. This is a JSON formatted string. See more details about [Policy Parameters](http://docs.aws.amazon.com/AmazonECR/latest/userguide/LifecyclePolicies.html#lifecycle_policy_parameters) in the official AWS docs.
    """
    registry_id: pulumi.Output[str]
    """
    The registry ID where the repository was created.
    """
    repository: pulumi.Output[str]
    """
    Name of the repository to apply the policy.
    """
    def __init__(__self__, resource_name, opts=None, policy=None, repository=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an ECR repository lifecycle policy.

        > **NOTE:** Only one `ecr.LifecyclePolicy` resource can be used with the same ECR repository. To apply multiple rules, they must be combined in the `policy` JSON.

        > **NOTE:** The AWS ECR API seems to reorder rules based on `rulePriority`. If you define multiple rules that are not sorted in ascending `rulePriority` order in the this provider code, the resource will be flagged for recreation every deployment.

        ## Example Usage

        ### Policy on untagged image

        ```python
        import pulumi
        import pulumi_aws as aws

        foo = aws.ecr.Repository("foo")
        foopolicy = aws.ecr.LifecyclePolicy("foopolicy",
            policy=\"\"\"{
            "rules": [
                {
                    "rulePriority": 1,
                    "description": "Expire images older than 14 days",
                    "selection": {
                        "tagStatus": "untagged",
                        "countType": "sinceImagePushed",
                        "countUnit": "days",
                        "countNumber": 14
                    },
                    "action": {
                        "type": "expire"
                    }
                }
            ]
        }

        \"\"\",
            repository=foo.name)
        ```

        ### Policy on tagged image

        ```python
        import pulumi
        import pulumi_aws as aws

        foo = aws.ecr.Repository("foo")
        foopolicy = aws.ecr.LifecyclePolicy("foopolicy",
            policy=\"\"\"{
            "rules": [
                {
                    "rulePriority": 1,
                    "description": "Keep last 30 images",
                    "selection": {
                        "tagStatus": "tagged",
                        "tagPrefixList": ["v"],
                        "countType": "imageCountMoreThan",
                        "countNumber": 30
                    },
                    "action": {
                        "type": "expire"
                    }
                }
            ]
        }

        \"\"\",
            repository=foo.name)
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] policy: The policy document. This is a JSON formatted string. See more details about [Policy Parameters](http://docs.aws.amazon.com/AmazonECR/latest/userguide/LifecyclePolicies.html#lifecycle_policy_parameters) in the official AWS docs.
        :param pulumi.Input[str] repository: Name of the repository to apply the policy.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if policy is None:
                raise TypeError("Missing required property 'policy'")
            __props__['policy'] = policy
            if repository is None:
                raise TypeError("Missing required property 'repository'")
            __props__['repository'] = repository
            __props__['registry_id'] = None
        super(LifecyclePolicy, __self__).__init__(
            'aws:ecr/lifecyclePolicy:LifecyclePolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, policy=None, registry_id=None, repository=None):
        """
        Get an existing LifecyclePolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] policy: The policy document. This is a JSON formatted string. See more details about [Policy Parameters](http://docs.aws.amazon.com/AmazonECR/latest/userguide/LifecyclePolicies.html#lifecycle_policy_parameters) in the official AWS docs.
        :param pulumi.Input[str] registry_id: The registry ID where the repository was created.
        :param pulumi.Input[str] repository: Name of the repository to apply the policy.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["policy"] = policy
        __props__["registry_id"] = registry_id
        __props__["repository"] = repository
        return LifecyclePolicy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Table(pulumi.CustomResource):
    arn: pulumi.Output[str]
    """
    The arn of the table
    """
    attributes: pulumi.Output[list]
    """
    List of nested attribute definitions. Only required for `hash_key` and `range_key` attributes. Each attribute has two properties:

      * `name` (`str`) - The name of the index
      * `type` (`str`) - Attribute type, which must be a scalar type: `S`, `N`, or `B` for (S)tring, (N)umber or (B)inary data
    """
    billing_mode: pulumi.Output[str]
    """
    Controls how you are charged for read and write throughput and how you manage capacity. The valid values are `PROVISIONED` and `PAY_PER_REQUEST`. Defaults to `PROVISIONED`.
    """
    global_secondary_indexes: pulumi.Output[list]
    """
    Describe a GSI for the table;
    subject to the normal limits on the number of GSIs, projected
    attributes, etc.

      * `hash_key` (`str`) - The name of the hash key in the index; must be
        defined as an attribute in the resource.
      * `name` (`str`) - The name of the index
      * `nonKeyAttributes` (`list`) - Only required with `INCLUDE` as a
        projection type; a list of attributes to project into the index. These
        do not need to be defined as attributes on the table.
      * `projectionType` (`str`) - One of `ALL`, `INCLUDE` or `KEYS_ONLY`
        where `ALL` projects every attribute into the index, `KEYS_ONLY`
        projects just the hash and range key into the index, and `INCLUDE`
        projects only the keys specified in the _non_key_attributes_
        parameter.
      * `range_key` (`str`) - The name of the range key; must be defined
      * `read_capacity` (`float`) - The number of read units for this index. Must be set if billing_mode is set to PROVISIONED.
      * `write_capacity` (`float`) - The number of write units for this index. Must be set if billing_mode is set to PROVISIONED.
    """
    hash_key: pulumi.Output[str]
    """
    The name of the hash key in the index; must be
    defined as an attribute in the resource.
    """
    local_secondary_indexes: pulumi.Output[list]
    """
    Describe an LSI on the table;
    these can only be allocated *at creation* so you cannot change this
    definition after you have created the resource.

      * `name` (`str`) - The name of the index
      * `nonKeyAttributes` (`list`) - Only required with `INCLUDE` as a
        projection type; a list of attributes to project into the index. These
        do not need to be defined as attributes on the table.
      * `projectionType` (`str`) - One of `ALL`, `INCLUDE` or `KEYS_ONLY`
        where `ALL` projects every attribute into the index, `KEYS_ONLY`
        projects just the hash and range key into the index, and `INCLUDE`
        projects only the keys specified in the _non_key_attributes_
        parameter.
      * `range_key` (`str`) - The name of the range key; must be defined
    """
    name: pulumi.Output[str]
    """
    The name of the index
    """
    point_in_time_recovery: pulumi.Output[dict]
    """
    Point-in-time recovery options.

      * `enabled` (`bool`) - Indicates whether ttl is enabled (true) or disabled (false).
    """
    range_key: pulumi.Output[str]
    """
    The name of the range key; must be defined
    """
    read_capacity: pulumi.Output[float]
    """
    The number of read units for this index. Must be set if billing_mode is set to PROVISIONED.
    """
    replicas: pulumi.Output[list]
    """
    Configuration block(s) with [DynamoDB Global Tables V2 (version 2019.11.21)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html) replication configurations. Detailed below.

      * `regionName` (`str`) - Region name of the replica.
    """
    server_side_encryption: pulumi.Output[dict]
    """
    Encryption at rest options. AWS DynamoDB tables are automatically encrypted at rest with an AWS owned Customer Master Key if this argument isn't specified.

      * `enabled` (`bool`) - Indicates whether ttl is enabled (true) or disabled (false).
      * `kms_key_arn` (`str`) - The ARN of the CMK that should be used for the AWS KMS encryption.
        This attribute should only be specified if the key is different from the default DynamoDB CMK, `alias/aws/dynamodb`.
    """
    stream_arn: pulumi.Output[str]
    """
    The ARN of the Table Stream. Only available when `stream_enabled = true`
    """
    stream_enabled: pulumi.Output[bool]
    """
    Indicates whether Streams are to be enabled (true) or disabled (false).
    """
    stream_label: pulumi.Output[str]
    """
    A timestamp, in ISO 8601 format, for this stream. Note that this timestamp is not
    a unique identifier for the stream on its own. However, the combination of AWS customer ID,
    table name and this field is guaranteed to be unique.
    It can be used for creating CloudWatch Alarms. Only available when `stream_enabled = true`
    """
    stream_view_type: pulumi.Output[str]
    """
    When an item in the table is modified, StreamViewType determines what information is written to the table's stream. Valid values are `KEYS_ONLY`, `NEW_IMAGE`, `OLD_IMAGE`, `NEW_AND_OLD_IMAGES`.
    """
    tags: pulumi.Output[dict]
    """
    A map of tags to populate on the created table.
    """
    ttl: pulumi.Output[dict]
    """
    Defines ttl, has two properties, and can only be specified once:

      * `attributeName` (`str`) - The name of the table attribute to store the TTL timestamp in.
      * `enabled` (`bool`) - Indicates whether ttl is enabled (true) or disabled (false).
    """
    write_capacity: pulumi.Output[float]
    """
    The number of write units for this index. Must be set if billing_mode is set to PROVISIONED.
    """
    def __init__(__self__, resource_name, opts=None, attributes=None, billing_mode=None, global_secondary_indexes=None, hash_key=None, local_secondary_indexes=None, name=None, point_in_time_recovery=None, range_key=None, read_capacity=None, replicas=None, server_side_encryption=None, stream_enabled=None, stream_view_type=None, tags=None, ttl=None, write_capacity=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a DynamoDB table resource

        > **Note:** It is recommended to use [`ignoreChanges`](https://www.pulumi.com/docs/intro/concepts/programming-model/#ignorechanges) for `read_capacity` and/or `write_capacity` if there's [autoscaling policy](https://www.terraform.io/docs/providers/aws/r/appautoscaling_policy.html) attached to the table.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        basic_dynamodb_table = aws.dynamodb.Table("basic-dynamodb-table",
            attributes=[
                {
                    "name": "UserId",
                    "type": "S",
                },
                {
                    "name": "GameTitle",
                    "type": "S",
                },
                {
                    "name": "TopScore",
                    "type": "N",
                },
            ],
            billing_mode="PROVISIONED",
            global_secondary_indexes=[{
                "hashKey": "GameTitle",
                "name": "GameTitleIndex",
                "nonKeyAttributes": ["UserId"],
                "projectionType": "INCLUDE",
                "rangeKey": "TopScore",
                "readCapacity": 10,
                "writeCapacity": 10,
            }],
            hash_key="UserId",
            range_key="GameTitle",
            read_capacity=20,
            tags={
                "Environment": "production",
                "Name": "dynamodb-table-1",
            },
            ttl={
                "attributeName": "TimeToExist",
                "enabled": False,
            },
            write_capacity=20)
        ```

        ### Global Tables

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.dynamodb.Table("example",
            attributes=[{
                "name": "TestTableHashKey",
                "type": "S",
            }],
            billing_mode="PAY_PER_REQUEST",
            hash_key="TestTableHashKey",
            replicas=[
                {
                    "regionName": "us-east-2",
                },
                {
                    "regionName": "us-west-2",
                },
            ],
            stream_enabled=True,
            stream_view_type="NEW_AND_OLD_IMAGES")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] attributes: List of nested attribute definitions. Only required for `hash_key` and `range_key` attributes. Each attribute has two properties:
        :param pulumi.Input[str] billing_mode: Controls how you are charged for read and write throughput and how you manage capacity. The valid values are `PROVISIONED` and `PAY_PER_REQUEST`. Defaults to `PROVISIONED`.
        :param pulumi.Input[list] global_secondary_indexes: Describe a GSI for the table;
               subject to the normal limits on the number of GSIs, projected
               attributes, etc.
        :param pulumi.Input[str] hash_key: The name of the hash key in the index; must be
               defined as an attribute in the resource.
        :param pulumi.Input[list] local_secondary_indexes: Describe an LSI on the table;
               these can only be allocated *at creation* so you cannot change this
               definition after you have created the resource.
        :param pulumi.Input[str] name: The name of the index
        :param pulumi.Input[dict] point_in_time_recovery: Point-in-time recovery options.
        :param pulumi.Input[str] range_key: The name of the range key; must be defined
        :param pulumi.Input[float] read_capacity: The number of read units for this index. Must be set if billing_mode is set to PROVISIONED.
        :param pulumi.Input[list] replicas: Configuration block(s) with [DynamoDB Global Tables V2 (version 2019.11.21)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html) replication configurations. Detailed below.
        :param pulumi.Input[dict] server_side_encryption: Encryption at rest options. AWS DynamoDB tables are automatically encrypted at rest with an AWS owned Customer Master Key if this argument isn't specified.
        :param pulumi.Input[bool] stream_enabled: Indicates whether Streams are to be enabled (true) or disabled (false).
        :param pulumi.Input[str] stream_view_type: When an item in the table is modified, StreamViewType determines what information is written to the table's stream. Valid values are `KEYS_ONLY`, `NEW_IMAGE`, `OLD_IMAGE`, `NEW_AND_OLD_IMAGES`.
        :param pulumi.Input[dict] tags: A map of tags to populate on the created table.
        :param pulumi.Input[dict] ttl: Defines ttl, has two properties, and can only be specified once:
        :param pulumi.Input[float] write_capacity: The number of write units for this index. Must be set if billing_mode is set to PROVISIONED.

        The **attributes** object supports the following:

          * `name` (`pulumi.Input[str]`) - The name of the index
          * `type` (`pulumi.Input[str]`) - Attribute type, which must be a scalar type: `S`, `N`, or `B` for (S)tring, (N)umber or (B)inary data

        The **global_secondary_indexes** object supports the following:

          * `hash_key` (`pulumi.Input[str]`) - The name of the hash key in the index; must be
            defined as an attribute in the resource.
          * `name` (`pulumi.Input[str]`) - The name of the index
          * `nonKeyAttributes` (`pulumi.Input[list]`) - Only required with `INCLUDE` as a
            projection type; a list of attributes to project into the index. These
            do not need to be defined as attributes on the table.
          * `projectionType` (`pulumi.Input[str]`) - One of `ALL`, `INCLUDE` or `KEYS_ONLY`
            where `ALL` projects every attribute into the index, `KEYS_ONLY`
            projects just the hash and range key into the index, and `INCLUDE`
            projects only the keys specified in the _non_key_attributes_
            parameter.
          * `range_key` (`pulumi.Input[str]`) - The name of the range key; must be defined
          * `read_capacity` (`pulumi.Input[float]`) - The number of read units for this index. Must be set if billing_mode is set to PROVISIONED.
          * `write_capacity` (`pulumi.Input[float]`) - The number of write units for this index. Must be set if billing_mode is set to PROVISIONED.

        The **local_secondary_indexes** object supports the following:

          * `name` (`pulumi.Input[str]`) - The name of the index
          * `nonKeyAttributes` (`pulumi.Input[list]`) - Only required with `INCLUDE` as a
            projection type; a list of attributes to project into the index. These
            do not need to be defined as attributes on the table.
          * `projectionType` (`pulumi.Input[str]`) - One of `ALL`, `INCLUDE` or `KEYS_ONLY`
            where `ALL` projects every attribute into the index, `KEYS_ONLY`
            projects just the hash and range key into the index, and `INCLUDE`
            projects only the keys specified in the _non_key_attributes_
            parameter.
          * `range_key` (`pulumi.Input[str]`) - The name of the range key; must be defined

        The **point_in_time_recovery** object supports the following:

          * `enabled` (`pulumi.Input[bool]`) - Indicates whether ttl is enabled (true) or disabled (false).

        The **replicas** object supports the following:

          * `regionName` (`pulumi.Input[str]`) - Region name of the replica.

        The **server_side_encryption** object supports the following:

          * `enabled` (`pulumi.Input[bool]`) - Indicates whether ttl is enabled (true) or disabled (false).
          * `kms_key_arn` (`pulumi.Input[str]`) - The ARN of the CMK that should be used for the AWS KMS encryption.
            This attribute should only be specified if the key is different from the default DynamoDB CMK, `alias/aws/dynamodb`.

        The **ttl** object supports the following:

          * `attributeName` (`pulumi.Input[str]`) - The name of the table attribute to store the TTL timestamp in.
          * `enabled` (`pulumi.Input[bool]`) - Indicates whether ttl is enabled (true) or disabled (false).
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if attributes is None:
                raise TypeError("Missing required property 'attributes'")
            __props__['attributes'] = attributes
            __props__['billing_mode'] = billing_mode
            __props__['global_secondary_indexes'] = global_secondary_indexes
            if hash_key is None:
                raise TypeError("Missing required property 'hash_key'")
            __props__['hash_key'] = hash_key
            __props__['local_secondary_indexes'] = local_secondary_indexes
            __props__['name'] = name
            __props__['point_in_time_recovery'] = point_in_time_recovery
            __props__['range_key'] = range_key
            __props__['read_capacity'] = read_capacity
            __props__['replicas'] = replicas
            __props__['server_side_encryption'] = server_side_encryption
            __props__['stream_enabled'] = stream_enabled
            __props__['stream_view_type'] = stream_view_type
            __props__['tags'] = tags
            __props__['ttl'] = ttl
            __props__['write_capacity'] = write_capacity
            __props__['arn'] = None
            __props__['stream_arn'] = None
            __props__['stream_label'] = None
        super(Table, __self__).__init__(
            'aws:dynamodb/table:Table',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, attributes=None, billing_mode=None, global_secondary_indexes=None, hash_key=None, local_secondary_indexes=None, name=None, point_in_time_recovery=None, range_key=None, read_capacity=None, replicas=None, server_side_encryption=None, stream_arn=None, stream_enabled=None, stream_label=None, stream_view_type=None, tags=None, ttl=None, write_capacity=None):
        """
        Get an existing Table resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The arn of the table
        :param pulumi.Input[list] attributes: List of nested attribute definitions. Only required for `hash_key` and `range_key` attributes. Each attribute has two properties:
        :param pulumi.Input[str] billing_mode: Controls how you are charged for read and write throughput and how you manage capacity. The valid values are `PROVISIONED` and `PAY_PER_REQUEST`. Defaults to `PROVISIONED`.
        :param pulumi.Input[list] global_secondary_indexes: Describe a GSI for the table;
               subject to the normal limits on the number of GSIs, projected
               attributes, etc.
        :param pulumi.Input[str] hash_key: The name of the hash key in the index; must be
               defined as an attribute in the resource.
        :param pulumi.Input[list] local_secondary_indexes: Describe an LSI on the table;
               these can only be allocated *at creation* so you cannot change this
               definition after you have created the resource.
        :param pulumi.Input[str] name: The name of the index
        :param pulumi.Input[dict] point_in_time_recovery: Point-in-time recovery options.
        :param pulumi.Input[str] range_key: The name of the range key; must be defined
        :param pulumi.Input[float] read_capacity: The number of read units for this index. Must be set if billing_mode is set to PROVISIONED.
        :param pulumi.Input[list] replicas: Configuration block(s) with [DynamoDB Global Tables V2 (version 2019.11.21)](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables.V2.html) replication configurations. Detailed below.
        :param pulumi.Input[dict] server_side_encryption: Encryption at rest options. AWS DynamoDB tables are automatically encrypted at rest with an AWS owned Customer Master Key if this argument isn't specified.
        :param pulumi.Input[str] stream_arn: The ARN of the Table Stream. Only available when `stream_enabled = true`
        :param pulumi.Input[bool] stream_enabled: Indicates whether Streams are to be enabled (true) or disabled (false).
        :param pulumi.Input[str] stream_label: A timestamp, in ISO 8601 format, for this stream. Note that this timestamp is not
               a unique identifier for the stream on its own. However, the combination of AWS customer ID,
               table name and this field is guaranteed to be unique.
               It can be used for creating CloudWatch Alarms. Only available when `stream_enabled = true`
        :param pulumi.Input[str] stream_view_type: When an item in the table is modified, StreamViewType determines what information is written to the table's stream. Valid values are `KEYS_ONLY`, `NEW_IMAGE`, `OLD_IMAGE`, `NEW_AND_OLD_IMAGES`.
        :param pulumi.Input[dict] tags: A map of tags to populate on the created table.
        :param pulumi.Input[dict] ttl: Defines ttl, has two properties, and can only be specified once:
        :param pulumi.Input[float] write_capacity: The number of write units for this index. Must be set if billing_mode is set to PROVISIONED.

        The **attributes** object supports the following:

          * `name` (`pulumi.Input[str]`) - The name of the index
          * `type` (`pulumi.Input[str]`) - Attribute type, which must be a scalar type: `S`, `N`, or `B` for (S)tring, (N)umber or (B)inary data

        The **global_secondary_indexes** object supports the following:

          * `hash_key` (`pulumi.Input[str]`) - The name of the hash key in the index; must be
            defined as an attribute in the resource.
          * `name` (`pulumi.Input[str]`) - The name of the index
          * `nonKeyAttributes` (`pulumi.Input[list]`) - Only required with `INCLUDE` as a
            projection type; a list of attributes to project into the index. These
            do not need to be defined as attributes on the table.
          * `projectionType` (`pulumi.Input[str]`) - One of `ALL`, `INCLUDE` or `KEYS_ONLY`
            where `ALL` projects every attribute into the index, `KEYS_ONLY`
            projects just the hash and range key into the index, and `INCLUDE`
            projects only the keys specified in the _non_key_attributes_
            parameter.
          * `range_key` (`pulumi.Input[str]`) - The name of the range key; must be defined
          * `read_capacity` (`pulumi.Input[float]`) - The number of read units for this index. Must be set if billing_mode is set to PROVISIONED.
          * `write_capacity` (`pulumi.Input[float]`) - The number of write units for this index. Must be set if billing_mode is set to PROVISIONED.

        The **local_secondary_indexes** object supports the following:

          * `name` (`pulumi.Input[str]`) - The name of the index
          * `nonKeyAttributes` (`pulumi.Input[list]`) - Only required with `INCLUDE` as a
            projection type; a list of attributes to project into the index. These
            do not need to be defined as attributes on the table.
          * `projectionType` (`pulumi.Input[str]`) - One of `ALL`, `INCLUDE` or `KEYS_ONLY`
            where `ALL` projects every attribute into the index, `KEYS_ONLY`
            projects just the hash and range key into the index, and `INCLUDE`
            projects only the keys specified in the _non_key_attributes_
            parameter.
          * `range_key` (`pulumi.Input[str]`) - The name of the range key; must be defined

        The **point_in_time_recovery** object supports the following:

          * `enabled` (`pulumi.Input[bool]`) - Indicates whether ttl is enabled (true) or disabled (false).

        The **replicas** object supports the following:

          * `regionName` (`pulumi.Input[str]`) - Region name of the replica.

        The **server_side_encryption** object supports the following:

          * `enabled` (`pulumi.Input[bool]`) - Indicates whether ttl is enabled (true) or disabled (false).
          * `kms_key_arn` (`pulumi.Input[str]`) - The ARN of the CMK that should be used for the AWS KMS encryption.
            This attribute should only be specified if the key is different from the default DynamoDB CMK, `alias/aws/dynamodb`.

        The **ttl** object supports the following:

          * `attributeName` (`pulumi.Input[str]`) - The name of the table attribute to store the TTL timestamp in.
          * `enabled` (`pulumi.Input[bool]`) - Indicates whether ttl is enabled (true) or disabled (false).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["attributes"] = attributes
        __props__["billing_mode"] = billing_mode
        __props__["global_secondary_indexes"] = global_secondary_indexes
        __props__["hash_key"] = hash_key
        __props__["local_secondary_indexes"] = local_secondary_indexes
        __props__["name"] = name
        __props__["point_in_time_recovery"] = point_in_time_recovery
        __props__["range_key"] = range_key
        __props__["read_capacity"] = read_capacity
        __props__["replicas"] = replicas
        __props__["server_side_encryption"] = server_side_encryption
        __props__["stream_arn"] = stream_arn
        __props__["stream_enabled"] = stream_enabled
        __props__["stream_label"] = stream_label
        __props__["stream_view_type"] = stream_view_type
        __props__["tags"] = tags
        __props__["ttl"] = ttl
        __props__["write_capacity"] = write_capacity
        return Table(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class OpenIdConnectProvider(pulumi.CustomResource):
    arn: pulumi.Output[str]
    """
    The ARN assigned by AWS for this provider.
    """
    client_id_lists: pulumi.Output[list]
    """
    A list of client IDs (also known as audiences). When a mobile or web app registers with an OpenID Connect provider, they establish a value that identifies the application. (This is the value that's sent as the client_id parameter on OAuth requests.)
    """
    thumbprint_lists: pulumi.Output[list]
    """
    A list of server certificate thumbprints for the OpenID Connect (OIDC) identity provider's server certificate(s). 
    """
    url: pulumi.Output[str]
    """
    The URL of the identity provider. Corresponds to the _iss_ claim.
    """
    def __init__(__self__, resource_name, opts=None, client_id_lists=None, thumbprint_lists=None, url=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides an IAM OpenID Connect provider.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        default = aws.iam.OpenIdConnectProvider("default",
            client_id_lists=["266362248691-342342xasdasdasda-apps.googleusercontent.com"],
            thumbprint_lists=[],
            url="https://accounts.google.com")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] client_id_lists: A list of client IDs (also known as audiences). When a mobile or web app registers with an OpenID Connect provider, they establish a value that identifies the application. (This is the value that's sent as the client_id parameter on OAuth requests.)
        :param pulumi.Input[list] thumbprint_lists: A list of server certificate thumbprints for the OpenID Connect (OIDC) identity provider's server certificate(s). 
        :param pulumi.Input[str] url: The URL of the identity provider. Corresponds to the _iss_ claim.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if client_id_lists is None:
                raise TypeError("Missing required property 'client_id_lists'")
            __props__['client_id_lists'] = client_id_lists
            if thumbprint_lists is None:
                raise TypeError("Missing required property 'thumbprint_lists'")
            __props__['thumbprint_lists'] = thumbprint_lists
            if url is None:
                raise TypeError("Missing required property 'url'")
            __props__['url'] = url
            __props__['arn'] = None
        super(OpenIdConnectProvider, __self__).__init__(
            'aws:iam/openIdConnectProvider:OpenIdConnectProvider',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, client_id_lists=None, thumbprint_lists=None, url=None):
        """
        Get an existing OpenIdConnectProvider resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The ARN assigned by AWS for this provider.
        :param pulumi.Input[list] client_id_lists: A list of client IDs (also known as audiences). When a mobile or web app registers with an OpenID Connect provider, they establish a value that identifies the application. (This is the value that's sent as the client_id parameter on OAuth requests.)
        :param pulumi.Input[list] thumbprint_lists: A list of server certificate thumbprints for the OpenID Connect (OIDC) identity provider's server certificate(s). 
        :param pulumi.Input[str] url: The URL of the identity provider. Corresponds to the _iss_ claim.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["client_id_lists"] = client_id_lists
        __props__["thumbprint_lists"] = thumbprint_lists
        __props__["url"] = url
        return OpenIdConnectProvider(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Job(pulumi.CustomResource):
    allocated_capacity: pulumi.Output[float]
    """
    **DEPRECATED** (Optional) The number of AWS Glue data processing units (DPUs) to allocate to this Job. At least 2 DPUs need to be allocated; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory.
    """
    arn: pulumi.Output[str]
    """
    Amazon Resource Name (ARN) of Glue Job
    """
    command: pulumi.Output[dict]
    """
    The command of the job. Defined below.

      * `name` (`str`) - The name of the job command. Defaults to `glueetl`. Use `pythonshell` for Python Shell Job Type, `max_capacity` needs to be set if `pythonshell` is chosen.
      * `pythonVersion` (`str`) - The Python version being used to execute a Python shell job. Allowed values are 2 or 3.
      * `scriptLocation` (`str`) - Specifies the S3 path to a script that executes a job.
    """
    connections: pulumi.Output[list]
    """
    The list of connections used for this job.
    """
    default_arguments: pulumi.Output[dict]
    """
    The map of default arguments for this job. You can specify arguments here that your own job-execution script consumes, as well as arguments that AWS Glue itself consumes. For information about how to specify and consume your own Job arguments, see the [Calling AWS Glue APIs in Python](http://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html) topic in the developer guide. For information about the key-value pairs that AWS Glue consumes to set up your job, see the [Special Parameters Used by AWS Glue](http://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-glue-arguments.html) topic in the developer guide.
    """
    description: pulumi.Output[str]
    """
    Description of the job.
    """
    execution_property: pulumi.Output[dict]
    """
    Execution property of the job. Defined below.

      * `maxConcurrentRuns` (`float`) - The maximum number of concurrent runs allowed for a job. The default is 1.
    """
    glue_version: pulumi.Output[str]
    """
    The version of glue to use, for example "1.0". For information about available versions, see the [AWS Glue Release Notes](https://docs.aws.amazon.com/glue/latest/dg/release-notes.html).
    """
    max_capacity: pulumi.Output[float]
    """
    The maximum number of AWS Glue data processing units (DPUs) that can be allocated when this job runs. `Required` when `pythonshell` is set, accept either `0.0625` or `1.0`.
    """
    max_retries: pulumi.Output[float]
    """
    The maximum number of times to retry this job if it fails.
    """
    name: pulumi.Output[str]
    """
    The name you assign to this job. It must be unique in your account.
    """
    notification_property: pulumi.Output[dict]
    """
    Notification property of the job. Defined below.

      * `notifyDelayAfter` (`float`) - After a job run starts, the number of minutes to wait before sending a job run delay notification.
    """
    number_of_workers: pulumi.Output[float]
    """
    The number of workers of a defined workerType that are allocated when a job runs.
    """
    role_arn: pulumi.Output[str]
    """
    The ARN of the IAM role associated with this job.
    """
    security_configuration: pulumi.Output[str]
    """
    The name of the Security Configuration to be associated with the job.
    """
    tags: pulumi.Output[dict]
    """
    Key-value map of resource tags
    """
    timeout: pulumi.Output[float]
    """
    The job timeout in minutes. The default is 2880 minutes (48 hours).
    """
    worker_type: pulumi.Output[str]
    """
    The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, or G.2X.
    """
    def __init__(__self__, resource_name, opts=None, allocated_capacity=None, command=None, connections=None, default_arguments=None, description=None, execution_property=None, glue_version=None, max_capacity=None, max_retries=None, name=None, notification_property=None, number_of_workers=None, role_arn=None, security_configuration=None, tags=None, timeout=None, worker_type=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Glue Job resource.

        > Glue functionality, such as monitoring and logging of jobs, is typically managed with the `default_arguments` argument. See the [Special Parameters Used by AWS Glue](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html) topic in the Glue developer guide for additional information.

        ## Example Usage

        ### Python Job

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.glue.Job("example",
            command={
                "scriptLocation": f"s3://{aws_s3_bucket['example']['bucket']}/example.py",
            },
            role_arn=aws_iam_role["example"]["arn"])
        ```

        ### Scala Job

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.glue.Job("example",
            command={
                "scriptLocation": f"s3://{aws_s3_bucket['example']['bucket']}/example.scala",
            },
            default_arguments={
                "--job-language": "scala",
            },
            role_arn=aws_iam_role["example"]["arn"])
        ```

        ### Enabling CloudWatch Logs and Metrics

        ```python
        import pulumi
        import pulumi_aws as aws

        example_log_group = aws.cloudwatch.LogGroup("exampleLogGroup", retention_in_days=14)
        example_job = aws.glue.Job("exampleJob", default_arguments={
            "--continuous-log-logGroup": example_log_group.name,
            "--enable-continuous-cloudwatch-log": "true",
            "--enable-continuous-log-filter": "true",
            "--enable-metrics": "",
        })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] allocated_capacity: **DEPRECATED** (Optional) The number of AWS Glue data processing units (DPUs) to allocate to this Job. At least 2 DPUs need to be allocated; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory.
        :param pulumi.Input[dict] command: The command of the job. Defined below.
        :param pulumi.Input[list] connections: The list of connections used for this job.
        :param pulumi.Input[dict] default_arguments: The map of default arguments for this job. You can specify arguments here that your own job-execution script consumes, as well as arguments that AWS Glue itself consumes. For information about how to specify and consume your own Job arguments, see the [Calling AWS Glue APIs in Python](http://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html) topic in the developer guide. For information about the key-value pairs that AWS Glue consumes to set up your job, see the [Special Parameters Used by AWS Glue](http://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-glue-arguments.html) topic in the developer guide.
        :param pulumi.Input[str] description: Description of the job.
        :param pulumi.Input[dict] execution_property: Execution property of the job. Defined below.
        :param pulumi.Input[str] glue_version: The version of glue to use, for example "1.0". For information about available versions, see the [AWS Glue Release Notes](https://docs.aws.amazon.com/glue/latest/dg/release-notes.html).
        :param pulumi.Input[float] max_capacity: The maximum number of AWS Glue data processing units (DPUs) that can be allocated when this job runs. `Required` when `pythonshell` is set, accept either `0.0625` or `1.0`.
        :param pulumi.Input[float] max_retries: The maximum number of times to retry this job if it fails.
        :param pulumi.Input[str] name: The name you assign to this job. It must be unique in your account.
        :param pulumi.Input[dict] notification_property: Notification property of the job. Defined below.
        :param pulumi.Input[float] number_of_workers: The number of workers of a defined workerType that are allocated when a job runs.
        :param pulumi.Input[str] role_arn: The ARN of the IAM role associated with this job.
        :param pulumi.Input[str] security_configuration: The name of the Security Configuration to be associated with the job.
        :param pulumi.Input[dict] tags: Key-value map of resource tags
        :param pulumi.Input[float] timeout: The job timeout in minutes. The default is 2880 minutes (48 hours).
        :param pulumi.Input[str] worker_type: The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, or G.2X.

        The **command** object supports the following:

          * `name` (`pulumi.Input[str]`) - The name of the job command. Defaults to `glueetl`. Use `pythonshell` for Python Shell Job Type, `max_capacity` needs to be set if `pythonshell` is chosen.
          * `pythonVersion` (`pulumi.Input[str]`) - The Python version being used to execute a Python shell job. Allowed values are 2 or 3.
          * `scriptLocation` (`pulumi.Input[str]`) - Specifies the S3 path to a script that executes a job.

        The **execution_property** object supports the following:

          * `maxConcurrentRuns` (`pulumi.Input[float]`) - The maximum number of concurrent runs allowed for a job. The default is 1.

        The **notification_property** object supports the following:

          * `notifyDelayAfter` (`pulumi.Input[float]`) - After a job run starts, the number of minutes to wait before sending a job run delay notification.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['allocated_capacity'] = allocated_capacity
            if command is None:
                raise TypeError("Missing required property 'command'")
            __props__['command'] = command
            __props__['connections'] = connections
            __props__['default_arguments'] = default_arguments
            __props__['description'] = description
            __props__['execution_property'] = execution_property
            __props__['glue_version'] = glue_version
            __props__['max_capacity'] = max_capacity
            __props__['max_retries'] = max_retries
            __props__['name'] = name
            __props__['notification_property'] = notification_property
            __props__['number_of_workers'] = number_of_workers
            if role_arn is None:
                raise TypeError("Missing required property 'role_arn'")
            __props__['role_arn'] = role_arn
            __props__['security_configuration'] = security_configuration
            __props__['tags'] = tags
            __props__['timeout'] = timeout
            __props__['worker_type'] = worker_type
            __props__['arn'] = None
        super(Job, __self__).__init__(
            'aws:glue/job:Job',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, allocated_capacity=None, arn=None, command=None, connections=None, default_arguments=None, description=None, execution_property=None, glue_version=None, max_capacity=None, max_retries=None, name=None, notification_property=None, number_of_workers=None, role_arn=None, security_configuration=None, tags=None, timeout=None, worker_type=None):
        """
        Get an existing Job resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] allocated_capacity: **DEPRECATED** (Optional) The number of AWS Glue data processing units (DPUs) to allocate to this Job. At least 2 DPUs need to be allocated; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory.
        :param pulumi.Input[str] arn: Amazon Resource Name (ARN) of Glue Job
        :param pulumi.Input[dict] command: The command of the job. Defined below.
        :param pulumi.Input[list] connections: The list of connections used for this job.
        :param pulumi.Input[dict] default_arguments: The map of default arguments for this job. You can specify arguments here that your own job-execution script consumes, as well as arguments that AWS Glue itself consumes. For information about how to specify and consume your own Job arguments, see the [Calling AWS Glue APIs in Python](http://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html) topic in the developer guide. For information about the key-value pairs that AWS Glue consumes to set up your job, see the [Special Parameters Used by AWS Glue](http://docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-glue-arguments.html) topic in the developer guide.
        :param pulumi.Input[str] description: Description of the job.
        :param pulumi.Input[dict] execution_property: Execution property of the job. Defined below.
        :param pulumi.Input[str] glue_version: The version of glue to use, for example "1.0". For information about available versions, see the [AWS Glue Release Notes](https://docs.aws.amazon.com/glue/latest/dg/release-notes.html).
        :param pulumi.Input[float] max_capacity: The maximum number of AWS Glue data processing units (DPUs) that can be allocated when this job runs. `Required` when `pythonshell` is set, accept either `0.0625` or `1.0`.
        :param pulumi.Input[float] max_retries: The maximum number of times to retry this job if it fails.
        :param pulumi.Input[str] name: The name you assign to this job. It must be unique in your account.
        :param pulumi.Input[dict] notification_property: Notification property of the job. Defined below.
        :param pulumi.Input[float] number_of_workers: The number of workers of a defined workerType that are allocated when a job runs.
        :param pulumi.Input[str] role_arn: The ARN of the IAM role associated with this job.
        :param pulumi.Input[str] security_configuration: The name of the Security Configuration to be associated with the job.
        :param pulumi.Input[dict] tags: Key-value map of resource tags
        :param pulumi.Input[float] timeout: The job timeout in minutes. The default is 2880 minutes (48 hours).
        :param pulumi.Input[str] worker_type: The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, or G.2X.

        The **command** object supports the following:

          * `name` (`pulumi.Input[str]`) - The name of the job command. Defaults to `glueetl`. Use `pythonshell` for Python Shell Job Type, `max_capacity` needs to be set if `pythonshell` is chosen.
          * `pythonVersion` (`pulumi.Input[str]`) - The Python version being used to execute a Python shell job. Allowed values are 2 or 3.
          * `scriptLocation` (`pulumi.Input[str]`) - Specifies the S3 path to a script that executes a job.

        The **execution_property** object supports the following:

          * `maxConcurrentRuns` (`pulumi.Input[float]`) - The maximum number of concurrent runs allowed for a job. The default is 1.

        The **notification_property** object supports the following:

          * `notifyDelayAfter` (`pulumi.Input[float]`) - After a job run starts, the number of minutes to wait before sending a job run delay notification.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["allocated_capacity"] = allocated_capacity
        __props__["arn"] = arn
        __props__["command"] = command
        __props__["connections"] = connections
        __props__["default_arguments"] = default_arguments
        __props__["description"] = description
        __props__["execution_property"] = execution_property
        __props__["glue_version"] = glue_version
        __props__["max_capacity"] = max_capacity
        __props__["max_retries"] = max_retries
        __props__["name"] = name
        __props__["notification_property"] = notification_property
        __props__["number_of_workers"] = number_of_workers
        __props__["role_arn"] = role_arn
        __props__["security_configuration"] = security_configuration
        __props__["tags"] = tags
        __props__["timeout"] = timeout
        __props__["worker_type"] = worker_type
        return Job(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

